@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8225 $
-## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
+## |  File version: $Revision: 8579 $
+## |  Last changed: $Date: 2025-03-04 16:57:07 +0100 (Di, 04 Mrz 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -26,11 +26,18 @@ PlotSubTitleItem <- R6::R6Class("PlotSubTitleItem",
         digits = NULL,
         initialize = function(..., title, value, subscript = NA_character_, digits = 3L) {
             self$title <- trimws(title)
-            self$value <- value
             self$subscript <- trimws(subscript)
             self$digits <- digits
 
-            self$value <- round(value, digits)
+            if (is.numeric(value)) {
+                self$value <- round(value, digits)
+            } else {
+                self$value <- value
+            }
+            
+            if (length(self$value) > 1) {
+                self$value <- .arrayToString(self$value, vectorLookAndFeelEnabled = TRUE)
+            }
         },
         show = function() {
             cat(self$toString(), "\n")
@@ -138,10 +145,10 @@ PlotSubTitleItems <- R6::R6Class("PlotSubTitleItems",
                     atop(.(self$subtitle) * "," ~ .(quotedItems))
                 )))
             }
-
+            
             return(bquote(atop(
                 bold(.(self$title)),
-                atop(.(self$quotedItems))
+                atop(.(quotedItems))
             )))
         },
         .getQuotedItems = function() {
@@ -165,78 +172,78 @@ PlotSubTitleItems <- R6::R6Class("PlotSubTitleItems",
             if (!is.null(item1) && !is.null(item2) && !is.null(item3) && !is.null(item4)) {
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript) &&
                         length(item2$subscript) == 1 && !is.na(item2$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) *
-                        "," ~ .(item2$title)[.(item2$subscript)] == .(item2$value) * "," ~
-                        .(item3$title) == .(item3$value) * "," ~ .(item4$title) == .(item4$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) *
+                        "," ~ .(item2$title)[.(item2$subscript)] * " " == .(item2$value) * "," ~
+                        .(item3$title) * " " == .(item3$value) * "," ~ .(item4$title) * " " == .(item4$value) * ""))
                 }
 
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) *
-                        "," ~ .(item2$title) == .(item2$value) * "," ~
-                        .(item3$title) == .(item3$value) * "," ~ .(item4$title) == .(item4$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) *
+                        "," ~ .(item2$title) * " " == .(item2$value) * "," ~
+                        .(item3$title) * " " == .(item3$value) * "," ~ .(item4$title) * " " == .(item4$value) * ""))
                 }
 
                 if (length(item2$subscript) == 1 && !is.na(item2$subscript)) {
-                    return(bquote(" " * .(item1$title) == .(item1$value) * "," ~
-                        .(item2$title)[.(item2$subscript)] == .(item2$value) *
-                            "," ~ .(item3$title) == .(item3$value) * "," ~ .(item4$title) == .(item4$value) * ""))
+                    return(bquote(" " * .(item1$title) * " " == .(item1$value) * "," ~
+                        .(item2$title)[.(item2$subscript)] * " " == .(item2$value) *
+                            "," ~ .(item3$title) * " " == .(item3$value) * "," ~ .(item4$title) * " " == .(item4$value) * ""))
                 }
 
-                return(bquote(" " * .(item1$title) == .(item1$value) * "," ~
-                    .(item2$title) == .(item2$value) * "," ~ .(item3$title) == .(item3$value) *
-                    "," ~ .(item4$title) == .(item4$value) * ""))
+                return(bquote(" " * .(item1$title) * " " == .(item1$value) * "," ~
+                    .(item2$title) * " " == .(item2$value) * "," ~ .(item3$title) * " " == .(item3$value) *
+                    "," ~ .(item4$title) * " " == .(item4$value) * ""))
             }
 
             if (!is.null(item1) && !is.null(item2) && !is.null(item3)) {
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript) &&
                         length(item2$subscript) == 1 && !is.na(item2$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) *
-                        "," ~ .(item2$title)[.(item2$subscript)] == .(item2$value) *
-                        "," ~ .(item3$title) == .(item3$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) *
+                        "," ~ .(item2$title)[.(item2$subscript)] * " " == .(item2$value) *
+                        "," ~ .(item3$title) * " " == .(item3$value) * ""))
                 }
 
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) *
-                        "," ~ .(item2$title) == .(item2$value) * "," ~ .(item3$title) == .(item3$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) *
+                        "," ~ .(item2$title) * " " == .(item2$value) * "," ~ .(item3$title) * " " == .(item3$value) * ""))
                 }
 
                 if (length(item2$subscript) == 1 && !is.na(item2$subscript)) {
-                    return(bquote(" " * .(item1$title) == .(item1$value) * "," ~
-                        .(item2$title)[.(item2$subscript)] == .(item2$value) *
-                            "," ~ .(item3$title) == .(item3$value) * ""))
+                    return(bquote(" " * .(item1$title) * " " == .(item1$value) * "," ~
+                        .(item2$title)[.(item2$subscript)] * " " == .(item2$value) *
+                            "," ~ .(item3$title) * " " == .(item3$value) * ""))
                 }
 
-                return(bquote(" " * .(item1$title) == .(item1$value) * "," ~
-                    .(item2$title) == .(item2$value) * "," ~ .(item3$title) == .(item3$value) * ""))
+                return(bquote(" " * .(item1$title) * " " == .(item1$value) * "," ~
+                    .(item2$title) * " " == .(item2$value) * "," ~ .(item3$title) * " " == .(item3$value) * ""))
             }
 
             if (!is.null(item1) && !is.null(item2)) {
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript) &&
                         length(item2$subscript) == 1 && !is.na(item2$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) *
-                        "," ~ .(item2$title)[.(item2$subscript)] == .(item2$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) *
+                        "," ~ .(item2$title)[.(item2$subscript)] * " " == .(item2$value) * ""))
                 }
 
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) *
-                        "," ~ .(item2$title) == .(item2$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) *
+                        "," ~ .(item2$title) * " " == .(item2$value) * ""))
                 }
 
                 if (length(item2$subscript) == 1 && !is.na(item2$subscript)) {
-                    return(bquote(" " * .(item1$title) == .(item1$value) * "," ~
-                        .(item2$title)[.(item2$subscript)] == .(item2$value) * ""))
+                    return(bquote(" " * .(item1$title) * " " == .(item1$value) * "," ~
+                        .(item2$title)[.(item2$subscript)] * " " == .(item2$value) * ""))
                 }
 
-                return(bquote(" " * .(item1$title) == .(item1$value) * "," ~
-                    .(item2$title) == .(item2$value) * ""))
+                return(bquote(" " * .(item1$title) * " " == .(item1$value) * "," ~
+                    .(item2$title) * " " == .(item2$value) * ""))
             }
 
             if (!is.null(item1)) {
                 if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
-                    return(bquote(" " * .(item1$title)[.(item1$subscript)] == .(item1$value) * ""))
+                    return(bquote(" " * .(item1$title)[.(item1$subscript)] * " " == .(item1$value) * ""))
                 }
 
-                return(bquote(" " * .(item1$title) == .(item1$value) * ""))
+                return(bquote(" " * .(item1$title) * " " == .(item1$value) * ""))
             }
 
             return(NULL)
@@ -491,10 +498,32 @@ PlotSettings <- R6::R6Class("PlotSettings",
             p <- p + ggplot2::theme(legend.text = ggplot2::element_text(size = self$scaleSize(self$legendFontSize)))
             return(p)
         },
+        getLegendPositionArguments = function(position, justification) {
+            if (packageVersion("ggplot2") < "3.5.0") {
+                return(list(
+                    legend.position = position, 
+                    legend.justification = justification
+                ))
+            }
+            
+            return(list(
+                legend.position = "inside",
+                legend.position.inside = position, 
+                legend.justification = justification
+            ))
+        },
         setLegendPosition = function(p, legendPosition) {
             .assertIsValidLegendPosition(legendPosition)
 
-            switch(as.character(legendPosition),
+            legendPosition <- as.character(legendPosition)
+            
+            if (legendPosition %in% c("none", "left", "right", "bottom", "top")) {
+                p <- p + ggplot2::theme(legend.position = legendPosition)
+                return(p)
+            }
+            
+            args <- list()
+            switch(legendPosition,
                 "-1" = {
                     p <- p + ggplot2::theme(legend.position = "none")
                 },
@@ -502,43 +531,29 @@ PlotSettings <- R6::R6Class("PlotSettings",
                     p <- p + ggplot2::theme(aspect.ratio = 1)
                 },
                 "1" = {
-                    p <- p + ggplot2::theme(
-                        legend.position = "inside",
-                        legend.position.inside = c(0.05, 1), legend.justification = c(0, 1)
-                    )
+                    args <- self$getLegendPositionArguments(c(0.05, 1), c(0, 1))
                 },
                 "2" = {
-                    p <- p + ggplot2::theme(
-                        legend.position = "inside",
-                        legend.position.inside = c(0.05, 0.5), legend.justification = c(0, 0.5)
-                    )
+                    args <- self$getLegendPositionArguments(c(0.05, 0.5), c(0, 0.5))
                 },
                 "3" = {
-                    p <- p + ggplot2::theme(
-                        legend.position = "inside",
-                        legend.position.inside = c(0.05, 0.05), legend.justification = c(0, 0)
-                    )
+                    args <- self$getLegendPositionArguments(c(0.05, 0.05), c(0, 0))
                 },
                 "4" = {
-                    p <- p + ggplot2::theme(
-                        legend.position = "inside",
-                        legend.position.inside = c(0.95, 1), legend.justification = c(1, 1)
-                    )
+                    args <- self$getLegendPositionArguments(c(0.95, 1), c(1, 1))
                 },
                 "5" = {
-                    p <- p + ggplot2::theme(
-                        legend.position = "inside",
-                        legend.position.inside = c(0.95, 0.5), legend.justification = c(1, 0.5)
-                    )
+                    args <- self$getLegendPositionArguments(c(0.95, 0.5), c(1, 0.5))
                 },
                 "6" = {
-                    p <- p + ggplot2::theme(
-                        legend.position = "inside",
-                        legend.position.inside = c(0.95, 0.05), legend.justification = c(1, 0)
-                    )
+                    args <- self$getLegendPositionArguments(c(0.95, 0.05), c(1, 0))
                 }
             )
-
+            
+            if (length(args) > 0) {
+                p <- p + do.call(ggplot2::theme, args) 
+            }
+            
             return(p)
         },
         setLegendBorder = function(p) {
@@ -585,6 +600,7 @@ PlotSettings <- R6::R6Class("PlotSettings",
             "Sets the main title"
 
             caption <- NA_character_
+            self$.htmlTitle <- NA_character_
             if (!is.null(mainTitle) && inherits(mainTitle, "PlotSubTitleItems")) {
                 plotLabsType <- getOption("rpact.plot.labs.type", "quote")
                 if (plotLabsType == "quote") {
@@ -619,6 +635,8 @@ PlotSettings <- R6::R6Class("PlotSettings",
                         self$.htmlTitle <- items$toHtml()
                     }
                 }
+            } else if (!is.null(mainTitle)) {
+                self$.htmlTitle <- mainTitle
             }
 
             subtitleFontSize <- NA_real_
@@ -638,9 +656,13 @@ PlotSettings <- R6::R6Class("PlotSettings",
                 p <- p + ggplot2::ggtitle(mainTitle)
             }
 
-            p <- p + ggplot2::theme(plot.title = ggplot2::element_text(
-                hjust = 0.5, size = self$scaleSize(self$mainTitleFontSize), face = "bold"
-            ))
+            p <- p + ggplot2::theme(
+                plot.title = ggplot2::element_text(
+                    hjust = 0.5, 
+                    size = self$scaleSize(self$mainTitleFontSize), 
+                    face = "bold"
+                )
+            )
 
             if (!is.na(subtitleFontSize)) {
                 p <- p + ggplot2::theme(
@@ -663,7 +685,8 @@ PlotSettings <- R6::R6Class("PlotSettings",
             if (!(length(margin) %in% c(1, 4))) {
                 stop(
                     C_EXCEPTION_TYPE_RUNTIME_ISSUE, "'margin' (", .arrayToString(margin),
-                    ") must be a numeric vector with length 1 or 4"
+                    ") must be a numeric vector with length 1 or 4", 
+                    call. = FALSE
                 )
             }
             p <- p + ggplot2::theme(plot.margin = ggplot2::unit(margin, "cm"))
