@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8225 $
-## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
+## |  File version: $Revision: 8416 $
+## |  Last changed: $Date: 2024-11-18 16:13:44 +0100 (Mo, 18 Nov 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -52,7 +52,7 @@ NULL
 .warnInCaseOfUnusedConditionalPowerArgument <- function(results, nPlanned, paramName, paramValues) {
     if (!.isConditionalPowerEnabled(nPlanned)) {
         if (length(paramValues) > 0 && !all(is.na(paramValues)) &&
-                results$.getParameterType(paramName) != C_PARAM_GENERATED) {
+                !results$isGeneratedParameter(paramName)) {
             warning("'", paramName, "' (", .arrayToString(paramValues), ") ",
                 "will be ignored because 'nPlanned' is not defined",
                 call. = FALSE
@@ -62,7 +62,7 @@ NULL
     }
     if (results$.design$kMax == 1) {
         if (length(paramValues) > 0 && !all(is.na(paramValues)) &&
-                results$.getParameterType(paramName) != C_PARAM_GENERATED) {
+                !results$isGeneratedParameter(paramName)) {
             warning("'", paramName, "' (", .arrayToString(paramValues), ") ",
                 "will be ignored because design is fixed",
                 call. = FALSE
@@ -975,210 +975,6 @@ getLongFormat <- function(dataInput) {
     return(invisible(results))
 }
 
-.getRecalculatedInformationRates <- function(dataInput, maxInformation, stage = NA_integer_) {
-    .assertIsSingleInteger(stage, "stage", naAllowed = TRUE, validateType = FALSE)
-    stageFromData <- dataInput$getNumberOfStages()
-    if (is.null(stage) || is.na(stage) || stage > stageFromData) {
-        stage <- stageFromData
-    }
-    informationRates <- rep(NA_real_, stage)
-    absoluteInformations <- rep(NA_real_, stage)
-    if (.isDatasetMeans(dataInput) || .isDatasetRates(dataInput)) {
-        for (k in 1:stage) {
-            sampleSizes <- dataInput$getOverallSampleSizes(stage = k)
-            absoluteInformations[k] <- sum(sampleSizes, na.rm = TRUE)
-            informationRates[k] <- absoluteInformations[k] / maxInformation
-        }
-    } else if (.isDatasetSurvival(dataInput)) {
-        for (k in 1:stage) {
-            events <- dataInput$getOverallEvents(stage = k)
-            absoluteInformations[k] <- sum(events, na.rm = TRUE)
-            informationRates[k] <- absoluteInformations[k] / maxInformation
-        }
-    } else {
-        stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "'dataInput' class ", .getClassName(dataInput), " is not supported")
-    }
-    return(list(informationRates = informationRates, absoluteInformations = absoluteInformations, stage = stage))
-}
-
-#' @title
-#' Get Observed Information Rates
-#'
-#' @description
-#' Recalculates the observed information rates from the specified dataset.
-#'
-#' @param dataInput The dataset for which the information rates shall be recalculated.
-#' @inheritParams param_maxInformation
-#' @inheritParams param_informationEpsilon
-#' @inheritParams param_stage
-#' @inheritParams param_three_dots
-#'
-#' @details
-#' For means and rates the maximum information is the maximum number of subjects
-#' or the relative proportion if \code{informationEpsilon} < 1;
-#' for survival data it is the maximum number of events
-#' or the relative proportion if \code{informationEpsilon} < 1.
-#'
-#' @seealso
-#' \itemize{
-#'   \item \code{\link[=getAnalysisResults]{getAnalysisResults()}} for using
-#'         \code{getObservedInformationRates()} implicit,
-#'   \item \href{https://www.rpact.org/vignettes/planning/rpact_boundary_update_example/}{www.rpact.org/vignettes/planning/rpact_boundary_update_example}
-#' }
-#'
-#' @examples
-#' \dontrun{
-#' # Absolute information epsilon:
-#' # decision rule 45 >= 46 - 1, i.e., under-running
-#' data <- getDataset(
-#'     overallN = c(22, 45),
-#'     overallEvents = c(11, 28)
-#' )
-#' getObservedInformationRates(data,
-#'     maxInformation = 46, informationEpsilon = 1
-#' )
-#'
-#' # Relative information epsilon:
-#' # last information rate = 45/46 = 0.9783,
-#' # is > 1 - 0.03 = 0.97, i.e., under-running
-#' data <- getDataset(
-#'     overallN = c(22, 45),
-#'     overallEvents = c(11, 28)
-#' )
-#' getObservedInformationRates(data,
-#'     maxInformation = 46, informationEpsilon = 0.03
-#' )
-#' }
-#'
-#' @return Returns a list that summarizes the observed information rates.
-#'
-#' @export
-#'
-getObservedInformationRates <- function(dataInput, ...,
-        maxInformation = NULL, informationEpsilon = NULL, stage = NA_integer_) {
-    .assertIsDataset(dataInput)
-    .assertIsSingleInteger(maxInformation, "maxInformation", validateType = FALSE)
-
-    information <- .getRecalculatedInformationRates(dataInput, maxInformation, stage = stage)
-    informationRates <- information$informationRates
-    absoluteInformations <- information$absoluteInformations
-    stage <- information$stage
-
-    status <- "interim-stage"
-
-    showObservedInformationRatesMessage <- .getOptionalArgument("showObservedInformationRatesMessage", ...)
-    if (is.null(showObservedInformationRatesMessage) || !is.logical(showObservedInformationRatesMessage)) {
-        showObservedInformationRatesMessage <- TRUE
-    }
-
-    # Updates at the final analysis in case the observed information at the final analysis
-    # is larger ("over-running") or smaller ("under-running") than the planned maximum information
-    if (informationRates[length(informationRates)] < 1) {
-        underRunningEnabled <- FALSE
-        if (!is.null(informationEpsilon)) {
-            .assertIsSingleNumber(informationEpsilon, "informationEpsilon")
-            .assertIsInOpenInterval(informationEpsilon, "informationEpsilon", lower = 0, upper = maxInformation)
-
-            lastInformationRate <- informationRates[length(informationRates)]
-            lastInformationNumber <- absoluteInformations[length(absoluteInformations)]
-
-            if (informationEpsilon < 1) {
-                if (lastInformationRate >= (1 - informationEpsilon)) {
-                    message(
-                        "Under-running: relative information epsilon ", round(informationEpsilon, 4), " is applicable; ",
-                        "use observed information ", lastInformationNumber, " instead of planned information ", maxInformation
-                    )
-                    information <- .getRecalculatedInformationRates(
-                        dataInput, lastInformationNumber,
-                        stage = stage
-                    )
-                    informationRates <- information$informationRates
-                    absoluteInformations <- information$absoluteInformations
-                    stage <- information$stage
-                    underRunningEnabled <- TRUE
-                    maxInformation <- lastInformationNumber
-                    showObservedInformationRatesMessage <- FALSE
-                }
-            } else {
-                if ((lastInformationNumber + informationEpsilon) >= maxInformation) {
-                    message(
-                        "Under-running: absolute information epsilon ", round(informationEpsilon, 1), " is applicable; ",
-                        "use observed information ", lastInformationNumber, " instead of planned information ", maxInformation
-                    )
-                    maxInformation <- lastInformationNumber
-                    information <- .getRecalculatedInformationRates(
-                        dataInput, lastInformationNumber,
-                        stage = stage
-                    )
-                    informationRates <- information$informationRates
-                    absoluteInformations <- information$absoluteInformations
-                    stage <- information$stage
-                    underRunningEnabled <- TRUE
-                    showObservedInformationRatesMessage <- FALSE
-                }
-            }
-        }
-
-        if (!underRunningEnabled) {
-            informationRates <- c(informationRates, 1)
-        } else {
-            status <- "under-running"
-        }
-    } else {
-        lastInformationNumber <- absoluteInformations[length(absoluteInformations)]
-        if (lastInformationNumber > maxInformation) {
-            information <- .getRecalculatedInformationRates(
-                dataInput, lastInformationNumber,
-                stage = stage
-            )
-            informationRates <- information$informationRates
-            absoluteInformations <- information$absoluteInformations
-            stage <- information$stage
-            message(
-                "Over-running: observed information ", lastInformationNumber, " at stage ", length(absoluteInformations),
-                " is larger than the maximum planned information ", maxInformation, "; information rates will be recalculated"
-            )
-            status <- "over-running"
-            maxInformation <- lastInformationNumber
-            showObservedInformationRatesMessage <- FALSE
-        }
-    }
-
-    if (any(informationRates > 1)) {
-        warning("The observed information at stage ",
-            .arrayToString(which(informationRates > 1)), " is over-running, ",
-            "i.e., the information rate (", .arrayToString(informationRates[informationRates > 1]), ") ",
-            "is larger than the planned maximum information rate (1)",
-            call. = FALSE
-        )
-    }
-
-    informationRates[informationRates > 1] <- 1
-
-    end <- min(which(informationRates == 1))
-    informationRates <- informationRates[1:end]
-
-    if (showObservedInformationRatesMessage) {
-        message(
-            "The observed information rates for 'maxInformation' = ", maxInformation,
-            " at stage ", stage, " are: ", .arrayToString(informationRates)
-        )
-    }
-
-    if (status == "interim-stage" && informationRates[length(informationRates)] == 1 &&
-            stage == length(informationRates)) {
-        status <- "final-stage"
-    }
-
-    return(list(
-        absoluteInformations = absoluteInformations,
-        maxInformation = maxInformation,
-        informationEpsilon = informationEpsilon,
-        informationRates = informationRates,
-        status = status
-    ))
-}
-
 .synchronizeIterationsAndSeed <- function(results) {
     if (is.null(results[[".conditionalPowerResults"]])) {
         stop(
