@@ -13,11 +13,12 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8624 $
+## |  Last changed: $Date: 2025-03-21 13:24:59 +0100 (Fr, 21 Mrz 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include class_dictionary.R
 #' @include f_core_utilities.R
 NULL
 
@@ -40,6 +41,7 @@ C_POSITION_LEFT_BOTTOM <- 3
 C_POSITION_RIGHT_TOP <- 4
 C_POSITION_RIGHT_CENTER <- 5
 C_POSITION_RIGHT_BOTTOM <- 6
+C_POSITION_OUTSIDE_BOTTOM <- "bottom"
 
 C_DESIGN_TOLERANCE_DEFAULT <- 1e-08
 C_CONST_NEWTON_COTES <- 15
@@ -51,9 +53,11 @@ C_ALPHA_DEFAULT <- 0.025
 C_BETA_DEFAULT <- 0.2
 C_SIDED_DEFAULT <- 1L
 C_KMAX_DEFAULT <- 3L
-C_KMAX_UPPER_BOUND <- 20L
+C_KMAX_UPPER_BOUND <- 50L
 C_KMAX_UPPER_BOUND_FISHER <- 6L
 
+C_MAX_NUMBER_OF_EFFECTS <- 50L
+
 C_NA_MAX_DEFAULT <- 100L
 C_POWER_ASN_THETA_DEFAULT <- seq(-1, 1, 0.02)
 
@@ -78,6 +82,8 @@ C_ACCEPT_DEVIATION_INFORMATIONRATES <- 0.05
 C_THETA_RANGE_SEQUENCE_LENGTH_DEFAULT <- 50
 C_VARIED_PARAMETER_SEQUENCE_LENGTH_DEFAULT <- 30
 
+C_HEADING_BASE_NUMBER_DEFAULT <- -2L
+
 C_CLASS_NAME_TRIAL_DESIGN_GROUP_SEQUENTIAL <- "TrialDesignGroupSequential"
 C_CLASS_NAME_TRIAL_DESIGN_INVERSE_NORMAL <- "TrialDesignInverseNormal"
 C_CLASS_NAME_TRIAL_DESIGN_FISHER <- "TrialDesignFisher"
@@ -95,6 +101,8 @@ C_CLASS_NAME_TRIAL_DESIGN_CONDITIONAL_DUNNETT <- "TrialDesignConditionalDunnett"
     return(trialDesignClassNames)
 }
 
+C_MARKDOWN_PLOT_PRINT_SEPARATOR <- "\n\n-----\n\n"
+
 C_EXCEPTION_TYPE_RUNTIME_ISSUE <- "Runtime exception: "
 C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT <- "Illegal argument: "
 C_EXCEPTION_TYPE_ILLEGAL_DATA_INPUT <- "Illegal data input: "
@@ -162,7 +170,7 @@ C_ALLOCATION_1_DEFAULT <- 1
 C_ALLOCATION_2_DEFAULT <- 1
 C_MAX_ITERATIONS_DEFAULT <- 10L
 C_MAX_SIMULATION_ITERATIONS_DEFAULT <- 1000L
-C_ACCRUAL_TIME_DEFAULT <- c(0, 12)
+C_ACCRUAL_TIME_DEFAULT <- c(0L, 12L)
 C_ACCRUAL_INTENSITY_DEFAULT <- 0.1
 C_FOLLOW_UP_TIME_DEFAULT <- 6
 
@@ -221,7 +229,7 @@ C_TYPE_OF_DESIGN_AS_USER <- "asUser" # user defined alpha spending
 C_TYPE_OF_DESIGN_NO_EARLY_EFFICACY <- "noEarlyEfficacy" # no early efficacy stop
 C_DEFAULT_TYPE_OF_DESIGN <- C_TYPE_OF_DESIGN_OF # the default type of design
 
-C_TYPE_OF_DESIGN_LIST <- list(
+C_TYPE_OF_DESIGN_LIST <- createDictionary("C_TYPE_OF_DESIGN_LIST", list(
     "OF" = "O'Brien & Fleming",
     "P" = "Pocock",
     "WT" = "Wang & Tsiatis Delta class",
@@ -234,7 +242,14 @@ C_TYPE_OF_DESIGN_LIST <- list(
     "asHSD" = "Hwang, Shi & DeCani alpha spending",
     "asUser" = "User defined alpha spending",
     "noEarlyEfficacy" = "No early efficacy stop"
-)
+))
+
+C_TYPE_OF_FISHER_LIST <- createDictionary("C_TYPE_OF_FISHER_LIST", list(
+    "equalAlpha" = "Constant levels",
+    "fullAlpha" = "Full last stage level",
+    "noInteraction" = "Levels with no Interaction",
+    "userDefinedAlpha" = "User defined levels"
+))
 
 C_PLOT_SHOW_SOURCE_ARGUMENTS <- c("commands", "axes", "test", "validate")
 
@@ -289,14 +304,14 @@ C_TYPE_OF_DESIGN_BS_KD <- "bsKD" # Kim & DeMets beta spending
 C_TYPE_OF_DESIGN_BS_HSD <- "bsHSD" # Hwang, Shi & DeCani beta spending
 C_TYPE_OF_DESIGN_BS_USER <- "bsUser" # user defined beta spending
 
-C_TYPE_OF_DESIGN_BS_LIST <- list(
+C_TYPE_OF_DESIGN_BS_LIST <- createDictionary("C_TYPE_OF_DESIGN_BS_LIST", list(
     "none" = "none",
     "bsP" = "Pocock type beta spending",
     "bsOF" = "O'Brien & Fleming type beta spending",
     "bsKD" = "Kim & DeMets beta spending",
     "bsHSD" = "Hwang, Shi & DeCani beta spending",
     "bsUser" = "user defined beta spending"
-)
+))
 
 C_CIPHERS <- list(token = "310818669631424001", secret = "9318655074497250732")
 
@@ -389,7 +404,7 @@ C_FISHER_METHOD_DEFAULT <- C_FISHER_METHOD_EQUAL_ALPHA
 ## -------------------------------------------
 ##
 
-C_PARAMETER_NAMES <- list(
+C_PARAMETER_NAMES <- createDictionary("C_PARAMETER_NAMES", list(
     iterations = "Iterations",
     seed = "Seed",
     groups = "Treatment groups",
@@ -398,6 +413,8 @@ C_PARAMETER_NAMES <- list(
     means = "Means",
     stDevs = "Standard deviations",
     overallEvents = "Cumulative events",
+    overallEvents1 = "Cumulative events (1)",
+    overallEvents2 = "Cumulative events (2)",
     overallAllocationRatios = "Cumulative allocation ratios",
     expectedEvents = "Expected events",
     varianceEvents = "Variance of events",
@@ -442,6 +459,7 @@ C_PARAMETER_NAMES <- list(
     theta = "Effect",
     direction = "Direction",
     normalApproximation = "Normal approximation",
+    conservative = "Conservative",
     equalVariances = "Equal variances",
     shift = "Shift",
     inflationFactor = "Inflation factor",
@@ -500,16 +518,11 @@ C_PARAMETER_NAMES <- list(
     overallStDevs1 = "Cumulative standard deviations (1)",
     overallStDevs2 = "Cumulative standard deviations (2)",
     overallStDevs = "Cumulative (pooled) standard deviations",
-    testStatistics = "Stage-wise test statistics",
     combInverseNormal = "Combination test statistics", # Inverse normal combination
     combFisher = "Combination test statistics", # Fisher combination
     weightsFisher = "Fixed weights",
     weightsInverseNormal = "Fixed weights",
     overallLogRanks = "Cumulative log-ranks",
-    overallEvents = "Cumulative number of events",
-    overallEvents1 = "Cumulative number of events (1)",
-    overallEvents2 = "Cumulative number of events (2)",
-    overallAllocationRatios = "Cumulative allocation ratios",
     events = "Number of events",
     allocationRatios = "Allocation ratios",
     logRanks = "Log-ranks",
@@ -546,6 +559,7 @@ C_PARAMETER_NAMES <- list(
     accountForObservationTimes = "Account for observation times",
     eventTime = "Event time",
     accrualTime = "Accrual time",
+    accrualTimeOriginal = "Accrual time",
     totalAccrualTime = "Total accrual time",
     remainingTime = "Remaining time",
     followUpTime = "Follow up time",
@@ -556,9 +570,7 @@ C_PARAMETER_NAMES <- list(
     expectedEventsH0 = "Expected number of events under H0",
     expectedEventsH01 = "Expected number of events under H0/H1",
     expectedEventsH1 = "Expected number of events under H1",
-    analysisTime = "Analysis times",
     studyDurationH1 = "Expected study duration under H1",
-    expectedNumberOfSubjectsH1 = "Expected number of subjects under H1",
     twoSidedPower = "Two-sided power",
     plannedEvents = "Planned cumulative events",
     plannedSubjects = "Planned cumulative subjects", # per arm (multi-arm); overall (base)
@@ -571,11 +583,7 @@ C_PARAMETER_NAMES <- list(
     maxNumberOfIterations = "Maximum number of iterations",
     allocation1 = "Allocation 1",
     allocation2 = "Allocation 2",
-    expectedNumberOfEvents = "Expected number of events",
-    expectedNumberOfEventsPerStage = "Expected number of events by stage",
-    eventsNotAchieved = "Events not achieved",
     subjects = "Subjects",
-    overallReject = "Overall reject",
     futilityStop = "Overall futility stop",
     studyDuration = "Expected study duration",
     maxStudyDuration = "Maximal study duration",
@@ -600,8 +608,8 @@ C_PARAMETER_NAMES <- list(
     futilityBoundsPValueScale = "Futility bounds (one-sided p-value scale)",
     futilityBoundsPValueScaleDelayedInformation = "Lower bounds of continuation (one-sided p-value scale)",
     analysisTime = "Analysis time",
-    eventsPerStage1 = "Observed # events by stage (1)",
-    eventsPerStage2 = "Observed # events by stage (2)",
+    eventsPerStage1 = "Observed events by stage (1)",
+    eventsPerStage2 = "Observed events by stage (2)",
     testStatistic = "Test statistic",
     logRankStatistic = "Log-rank statistic",
     hazardRatioEstimateLR = "Hazard ratio estimate LR",
@@ -611,10 +619,13 @@ C_PARAMETER_NAMES <- list(
     median1 = "median(1)",
     median2 = "median(2)",
     eventsPerStage = "Number of events per stage",
-    overallEventsPerStage = "Cumulative number of events",
-    expectedNumberOfEvents = "Observed number of events",
-    expectedNumberOfSubjects = "Observed number of subjects",
-    singleNumberOfEventsPerStage = "Single number of events",
+    expectedNumberOfEventsPerStage = "Expected number of events by stage",
+    eventsNotAchieved = "Events not achieved",
+    cumulativeEventsPerStage = "Cumulative number of events",
+    expectedNumberOfEvents = "Expected number of events",
+    singleEventsPerStage = "Single number of events",
+    singleEventsPerArmAndStage = "Single number of events",
+    singleEventsPerSubsetAndStage = "Single number of events",
     endOfAccrualIsUserDefined = "End of accrual is user defined",
     followUpTimeMustBeUserDefined = "Follow-up time must be user defined",
     maxNumberOfSubjectsIsUserDefined = "Max number of subjects is user defined",
@@ -643,6 +654,7 @@ C_PARAMETER_NAMES <- list(
     typeOfShape = "Type of shape",
     gED50 = "ED50",
     slope = "Slope",
+    doseLevels = "Dose levels",
     adaptations = "Adaptations",
     typeOfSelection = "Type of selection",
     effectMeasure = "Effect measure",
@@ -694,10 +706,22 @@ C_PARAMETER_NAMES <- list(
     locationConditionalPower = "Location conditional power",
     variationConditionalPower = "Variation conditional power",
     subscoreConditionalPower = "Sub-score conditional power",
-    performanceScore = "Performance scores"
-)
+    performanceScore = "Performance scores",
+    overdispersion = "Overdispersion",
+    lambda = "Lambda",
+    fixedExposureTime = "Fixed exposure time",
+    calendarTime = "Calendar time",
+    studyTime = "Study time",
+    studySubjects = "Study subjects",
+    expectedStudyDurationH1 = "Expected study duration under H1",
+    informationOverStages = "Information over stages",
+    expectedInformationH0 = "Expected information under H0",
+    expectedInformationH01 = "Expected information under H0/H1",
+    expectedInformationH1 = "Expected information under H1",
+    plannedCalendarTime = "Planned calendar time"
+))
 
-C_TABLE_COLUMN_NAMES <- list(
+C_TABLE_COLUMN_NAMES <- createDictionary("C_TABLE_COLUMN_NAMES", list(
     iterations = "Iterations",
     seed = "Seed",
     groups = "Treatment group",
@@ -706,6 +730,8 @@ C_TABLE_COLUMN_NAMES <- list(
     means = "Mean",
     stDevs = "Standard deviation",
     overallEvents = "Cumulative event",
+    overallEvents1 = "Cumulative events (1)",
+    overallEvents2 = "Cumulative events (2)",
     overallAllocationRatios = "Cumulative allocation ratio",
     overallMeans = "Cumulative mean",
     expectedEvents = "Expected event",
@@ -751,6 +777,7 @@ C_TABLE_COLUMN_NAMES <- list(
     theta = "Effect",
     direction = "Direction",
     normalApproximation = "Normal approximation",
+    conservative = "Conservative",
     equalVariances = "Equal variance",
     assumedStDev = "Assumed standard deviation",
     assumedStDevs = "Assumed standard deviation",
@@ -781,9 +808,7 @@ C_TABLE_COLUMN_NAMES <- list(
     overallPiTreatments = "Cumulative treatment rate",
     overallPisControl = "Cumulative control rate",
     overallPisTreatment = "Cumulative treatment rate",
-    stages = "Stage",
     effectSizes = "Overall effect size",
-    testStatistics = "Stage-wise test statistic",
     pValues = "p-value",
     testActions = "Action",
     conditionalPower = "Conditional power",
@@ -813,10 +838,6 @@ C_TABLE_COLUMN_NAMES <- list(
     weightsFisher = "Fixed weight",
     weightsInverseNormal = "Fixed weight",
     overallLogRanks = "Cumulative log-rank",
-    overallEvents = "Cumulative # events",
-    overallEvents1 = "Cumulative # events (1)",
-    overallEvents2 = "Cumulative # events (2)",
-    overallAllocationRatios = "Cumulative allocation ratio",
     events = "# events",
     allocationRatios = "Allocation ratio",
     logRanks = "Log-rank",
@@ -845,7 +866,6 @@ C_TABLE_COLUMN_NAMES <- list(
     expectedNumberOfSubjectsH0 = "Expected # subjects under H0",
     expectedNumberOfSubjectsH01 = "Expected # subjects under H0/H1",
     expectedNumberOfSubjectsH1 = "Expected # subjects under H1",
-    expectedNumberOfSubjects = "Expected # subjects",
     chi = "Probability of an event",
     hazardRatio = "Hazard ratio",
     hazardRatios = "Hazard ratios",
@@ -853,6 +873,7 @@ C_TABLE_COLUMN_NAMES <- list(
     accountForObservationTimes = "Account for observation times",
     eventTime = "Event time",
     accrualTime = "Accrual time",
+    accrualTimeOriginal = "Accrual time",
     totalAccrualTime = "Total accrual time",
     remainingTime = "Remaining time",
     followUpTime = "Follow up time",
@@ -860,14 +881,13 @@ C_TABLE_COLUMN_NAMES <- list(
     dropoutRate2 = "Drop-out rate (2)",
     dropoutTime = "Drop-out time",
     eventsFixed = "# events fixed",
-    expectedEventsH0 = "Expected # events under H0",
-    expectedEventsH01 = "Expected # events under H0/H1",
-    expectedEventsH1 = "Expected # events under H1",
+    expectedEventsH0 = "Expected events under H0",
+    expectedEventsH01 = "Expected events under H0/H1",
+    expectedEventsH1 = "Expected events under H1",
     analysisTime = "Analysis time",
-    eventsPerStage1 = "Observed # events by stage (1)",
-    eventsPerStage2 = "Observed # events by stage (2)",
+    eventsPerStage1 = "Observed events by stage (1)",
+    eventsPerStage2 = "Observed events by stage (2)",
     studyDurationH1 = "Expected study duration H1",
-    expectedNumberOfSubjectsH1 = "Expected # subjects H1",
     twoSidedPower = "Two-sided power",
     plannedEvents = "Planned cumulative events",
     plannedSubjects = "Planned cumulative subjects",
@@ -880,7 +900,6 @@ C_TABLE_COLUMN_NAMES <- list(
     maxNumberOfIterations = "Maximum # iterations",
     allocation1 = "Allocation 1",
     allocation2 = "Allocation 2",
-    expectedNumberOfEvents = "Expected # events",
     expectedNumberOfEventsPerStage = "Expected # events by stage",
     eventsNotAchieved = "Events not achieved",
     subjects = "Subjects",
@@ -912,12 +931,13 @@ C_TABLE_COLUMN_NAMES <- list(
     piecewiseSurvivalEnabled = "Piecewise exponential survival enabled",
     median1 = "median(1)",
     median2 = "median(2)",
-    eventsPerStage = "Cumulative # events",
-    eventsPerStage = "# events per stage",
-    overallEventsPerStage = "Cumulative # events",
-    expectedNumberOfEvents = "Observed # events",
-    expectedNumberOfSubjects = "Observed # subjects",
-    singleNumberOfEventsPerStage = "Single # events",
+    eventsPerStage = "Events per stage",
+    cumulativeEventsPerStage = "Cumulative events",
+    expectedNumberOfEvents = "Expected events",
+    expectedNumberOfSubjects = "Expected subjects",
+    singleEventsPerStage = "Single events",
+    singleEventsPerArmAndStage = "Single events",
+    singleEventsPerSubsetAndStage = "Single events",
     endOfAccrualIsUserDefined = "End of accrual is user defined",
     followUpTimeMustBeUserDefined = "Follow-up time must be user defined",
     maxNumberOfSubjectsIsUserDefined = "Max number of subjects is user defined",
@@ -946,6 +966,7 @@ C_TABLE_COLUMN_NAMES <- list(
     typeOfShape = "Type of shape",
     gED50 = "ED50",
     slope = "Slope",
+    doseLevels = "Dose levels",
     adaptations = "Adaptations",
     typeOfSelection = "Type of selection",
     effectMeasure = "Effect measure",
@@ -993,128 +1014,216 @@ C_TABLE_COLUMN_NAMES <- list(
     locationConditionalPower = "Location conditional power",
     variationConditionalPower = "Variation conditional power",
     subscoreConditionalPower = "Sub-score conditional power",
-    performanceScore = "Performance score"
-)
+    performanceScore = "Performance score",
+    overdispersion = "Overdispersion",
+    lambda = "Lambda",
+    fixedExposureTime = "Fixed exposure time",
+    calendarTime = "Calendar time",
+    studyTime = "Study time",
+    studySubjects = "Study subjects",
+    expectedStudyDurationH1 = "Expected study duration under H1",
+    informationOverStages = "Information over stages",
+    expectedInformationH0 = "Expected information under H0",
+    expectedInformationH01 = "Expected information under H0/H1",
+    expectedInformationH1 = "Expected information under H1",
+    plannedCalendarTime = "Planned calendar time"
+))
 
-.getParameterCaptions <- function(captionList, ...,
-        design = NULL,
-        designPlan = NULL,
-        stageResults = NULL,
-        analysisResults = NULL,
-        dataset = NULL,
-        designCharacteristics = NULL,
-        tableColumns = FALSE) {
-    parameterNames <- captionList
+C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETTINGS", list(
+    "lineSize" = "Line size",
+    "pointSize" = "Point size",
+    "pointColor" = "Point color",
+    "mainTitleFontSize" = "Main title font size",
+    "axesTextFontSize" = "Axes text font size",
+    "legendFontSize" = "Legend font size",
+    "scalingFactor" = "Scaling factor"
+))
 
-    if (!is.null(design)) {
-        parameterNameFutilityBounds <- "futilityBounds"
-        if (.isDelayedInformationEnabled(design = design)) {
-            if (!is.na(design$bindingFutility) && !design$bindingFutility) {
-                parameterNameFutilityBounds <- "futilityBoundsDelayedInformationNonBinding"
-            } else {
-                parameterNameFutilityBounds <- "futilityBoundsDelayedInformation"
+.getParameterNameTrialDesign <- function(parameterName, obj) {
+    if (inherits(obj, "TrialDesignSet") && length(obj$designs) > 0) {
+        obj <- obj$designs[[1]]
+    }
+
+    if (!inherits(obj, "TrialDesign")) {
+        obj <- obj[[".design"]]
+    }
+
+    if (is.null(obj) || !inherits(obj, "TrialDesign")) {
+        return(parameterName)
+    }
+
+    if (identical(parameterName, "futilityBounds")) {
+        if (.isDelayedInformationEnabled(design = obj)) {
+            if (!is.na(obj$bindingFutility) && !obj$bindingFutility) {
+                return("futilityBoundsDelayedInformationNonBinding")
             }
-            parameterNames$criticalValues <- captionList[["criticalValuesDelayedInformation"]]
-
-            parameterNames$criticalValuesEffectScale <- captionList[["criticalValuesEffectScaleDelayedInformation"]]
-            parameterNames$futilityBoundsEffectScale <- captionList[["futilityBoundsEffectScaleDelayedInformation"]]
-            parameterNames$futilityBoundsPValueScale <- captionList[["futilityBoundsPValueScaleDelayedInformation"]]
-        } else if (!is.na(design$bindingFutility) && !design$bindingFutility) {
-            parameterNameFutilityBounds <- "futilityBoundsNonBinding"
+            return("futilityBoundsDelayedInformation")
+        } else if (!is.na(obj$bindingFutility) && !obj$bindingFutility) {
+            return("futilityBoundsNonBinding")
         }
-        parameterNames$futilityBounds <- captionList[[parameterNameFutilityBounds]]
     }
-
-    if (!is.null(designPlan) && inherits(designPlan, "TrialDesignPlanSurvival") &&
-            !is.null(designPlan$.piecewiseSurvivalTime) &&
-            designPlan$.piecewiseSurvivalTime$piecewiseSurvivalEnabled) {
-        parameterNames$lambda2 <- "Piecewise survival lambda (2)"
-        parameterNames$lambda1 <- "Piecewise survival lambda (1)"
+    if (identical(parameterName, "criticalValues") && .isDelayedInformationEnabled(design = obj)) {
+        return("criticalValuesDelayedInformation")
     }
-
-    if (!is.null(designPlan) &&
-            inherits(designPlan, "TrialDesignPlanSurvival") &&
-            identical(designPlan$.design$kMax, 1L)) {
-        parameterNames$maxNumberOfEvents <- "Number of events"
+    if (identical(parameterName, "criticalValuesEffectScale") && .isDelayedInformationEnabled(design = obj)) {
+        return("criticalValuesEffectScaleDelayedInformation")
     }
-
-    if (!is.null(designPlan) && inherits(designPlan, "TrialDesignPlan") &&
-            identical(designPlan$.design$kMax, 1L)) {
-        parameterNames$studyDuration <- "Study duration"
+    if (identical(parameterName, "futilityBoundsEffectScale") && .isDelayedInformationEnabled(design = obj)) {
+        return("futilityBoundsEffectScaleDelayedInformation")
     }
+    if (identical(parameterName, "futilityBoundsPValueScale") && .isDelayedInformationEnabled(design = obj)) {
+        return("futilityBoundsPValueScaleDelayedInformation")
+    }
+    return(parameterName)
+}
 
-    if (!is.null(analysisResults)) {
-        pluralExt <- ifelse(tableColumns, "", "s")
-        if (.isTrialDesignConditionalDunnett(analysisResults$.design)) {
-            parameterNames$repeatedConfidenceIntervalLowerBounds <-
-                paste0("Overall confidence interval", pluralExt, " (lower)")
-            parameterNames$repeatedConfidenceIntervalUpperBounds <-
-                paste0("Overall confidence interval", pluralExt, " (upper)")
-            parameterNames$repeatedPValues <- paste0("Overall p-value", pluralExt)
-        } else if (identical(analysisResults$.design$kMax, 1L)) {
-            parameterNames$repeatedConfidenceIntervalLowerBounds <- paste0("Confidence interval", pluralExt, " (lower)")
-            parameterNames$repeatedConfidenceIntervalUpperBounds <- paste0("Confidence interval", pluralExt, " (upper)")
-            parameterNames$repeatedPValues <- paste0("Overall p-value", pluralExt)
+.getParameterCaption <- function(parameterName, obj = NULL, ..., tableOutputEnabled = FALSE) {
+    .assertIsSingleCharacter(parameterName, "parameterName")
+
+    if (grepl("\\$", parameterName)) {
+        parts <- strsplit(parameterName, "\\$", fixed = TRUE)[[1]]
+        if (length(parts) == 2) {
+            if (!is.null(obj[[parts[1]]])) {
+                obj <- obj[[parts[1]]]
+            }
+            parameterName <- parts[2]
         }
     }
 
-    if (!is.null(designPlan) &&
-            (inherits(designPlan, "TrialDesignPlanMeans") ||
-                inherits(designPlan, "SimulationResultsMeans")) &&
-            isTRUE(designPlan$meanRatio)) {
-        parameterNames$stDev <- "Coefficient of variation"
+    if (is.null(obj)) {
+        if (tableOutputEnabled) {
+            return(C_TABLE_COLUMN_NAMES[[parameterName]])
+        }
+
+        return(C_PARAMETER_NAMES[[parameterName]])
     }
 
-    if (!is.null(design) && .getClassName(design) != "TrialDesign" && design$sided == 2) {
-        parameterNames$criticalValuesPValueScale <- paste0("Local two-sided significance level", ifelse(tableColumns, "", "s"))
+    parameterName <- .getParameterNameTrialDesign(parameterName, obj)
+
+    if (inherits(obj, "PlotSettings")) {
+        return(C_PARAMETER_NAMES_PLOT_SETTINGS[[parameterName]])
     }
 
-    if ((!is.null(stageResults) && stageResults$isOneSampleDataset()) ||
-            (!is.null(dataset) && inherits(dataset, "DatasetMeans"))) {
-        parameterNames$overallStDevs <- paste0("Cumulative standard deviation", ifelse(tableColumns, "", "s"))
+    parameterName <- .getParameterNameTrialDesign(parameterName, obj)
+
+    pluralExt <- ifelse(tableOutputEnabled, "", "s")
+
+    if (identical(parameterName, "futilityBounds") &&
+            inherits(obj, "TrialDesignSet") && length(obj$designs) > 1) {
+        bindingFutilityValues <- logical(0)
+        for (design in obj$designs) {
+            bindingFutilityValues <- unique(c(bindingFutilityValues, design$bindingFutility))
+        }
+        if (length(bindingFutilityValues) > 1) {
+            return(paste0("Futility bound", pluralExt))
+        }
     }
 
-    return(parameterNames)
+    if (identical(parameterName, "eventsPerStage") &&
+            (inherits(obj, "TrialDesignPlanSurvival") ||
+                inherits(obj, "SimulationResultsMultiArmSurvival"))) {
+        return(ifelse(tableOutputEnabled, "Cumulative events", "Cumulative events per stage"))
+    }
+
+    if (identical(parameterName, "lambda1") &&
+            inherits(obj, "TrialDesignPlanSurvival") &&
+            !is.null(obj$.piecewiseSurvivalTime) &&
+            obj$.piecewiseSurvivalTime$piecewiseSurvivalEnabled) {
+        return("Piecewise survival lambda (1)")
+    }
+
+    if (identical(parameterName, "lambda2") &&
+            inherits(obj, "TrialDesignPlanSurvival") &&
+            !is.null(obj$.piecewiseSurvivalTime) &&
+            obj$.piecewiseSurvivalTime$piecewiseSurvivalEnabled) {
+        return("Piecewise survival lambda (2)")
+    }
+
+    if (identical(parameterName, "maxNumberOfEvents") &&
+            inherits(obj, "TrialDesignPlanSurvival") &&
+            identical(obj$.design$kMax, 1L)) {
+        return("Number of events")
+    }
+
+    if (identical(parameterName, "studyDuration") &&
+            inherits(obj, "TrialDesignPlan") &&
+            identical(obj$.design$kMax, 1L)) {
+        return("Study duration")
+    }
+
+    if (inherits(obj, "AnalysisResults")) {
+        if (identical(parameterName, "repeatedConfidenceIntervalLowerBounds") &&
+                .isTrialDesignConditionalDunnett(obj$.design)) {
+            return(paste0("Overall confidence interval", pluralExt, " (lower)"))
+        }
+        if (identical(parameterName, "repeatedConfidenceIntervalUpperBounds") &&
+                .isTrialDesignConditionalDunnett(obj$.design)) {
+            return(paste0("Overall confidence interval", pluralExt, " (upper)"))
+        }
+    }
+
+    if (identical(parameterName, "stDev") &&
+            (inherits(obj, "TrialDesignPlanMeans") || inherits(obj, "SimulationResultsMeans")) &&
+            isTRUE(obj$meanRatio)) {
+        return("Coefficient of variation")
+    }
+
+    if (identical(parameterName, "criticalValuesPValueScale") && inherits(obj, "TrailDesign") &&
+            .getClassName(obj) != "TrialDesign" && obj$sided == 2) {
+        return(paste0("Local two-sided significance level", ifelse(tableOutputEnabled, "", "s")))
+    }
+
+    if (identical(parameterName, "overallStDevs") &&
+            ((inherits(obj, "StageResults") && obj$isOneSampleDataset()) ||
+                inherits(obj, "DatasetMeans"))) {
+        return(paste0("Cumulative standard deviation", ifelse(tableOutputEnabled, "", "s")))
+    }
+
+    if (tableOutputEnabled) {
+        return(C_TABLE_COLUMN_NAMES[[parameterName]])
+    }
+
+    return(C_PARAMETER_NAMES[[parameterName]])
 }
 
-.getParameterNames <- function(...,
-        design = NULL,
-        designPlan = NULL,
-        stageResults = NULL,
-        analysisResults = NULL,
-        dataset = NULL,
-        designCharacteristics = NULL) {
-    .getParameterCaptions(
-        captionList = C_PARAMETER_NAMES,
-        design = design,
-        designPlan = designPlan,
-        stageResults = stageResults,
-        analysisResults = analysisResults,
-        dataset = dataset,
-        designCharacteristics = designCharacteristics
-    )
+.getParameterFormatFunction <- function(parameterName, obj = NULL) {
+    if (is.null(obj) || !inherits(obj, "FieldSet")) {
+        return(C_PARAMETER_FORMAT_FUNCTIONS[[parameterName]])
+    }
+
+    if (parameterName == "overallAdjustedTestStatistics" &&
+            inherits(obj, "ClosedCombinationTestResults") &&
+            !is.null(obj[[".design"]]) &&
+            inherits(obj$.design, C_CLASS_NAME_TRIAL_DESIGN_FISHER)) {
+        return(".formatTestStatisticsFisher")
+    }
+
+    if (parameterName == "maxInformation" && inherits(obj, "TrialDesignPlanCountData")) {
+        return(".formatRatesDynamic")
+    }
+
+    if (parameterName == "nFixed" && inherits(obj, "TrialDesignCharacteristics")) {
+        return(".formatProbabilities")
+    }
+
+    if (parameterName == "criticalValues" && inherits(obj, "TrialDesignFisher")) {
+        return(".formatCriticalValuesFisher")
+    }
+
+    if (parameterName == "accrualTime" && inherits(obj, "TrialDesignPlanCountData") &&
+            obj$.getParameterType("accrualTime") == C_PARAM_USER_DEFINED) {
+        return(".formatHowItIs")
+    }
+    
+    if (parameterName == "accrualTimeOriginal" && inherits(obj, "TrialDesignPlanCountData") &&
+            obj$.getParameterType("accrualTimeOriginal") == C_PARAM_USER_DEFINED) {
+        return(".formatHowItIs")
+    }
+
+    return(C_PARAMETER_FORMAT_FUNCTIONS[[parameterName]])
 }
 
-.getTableColumnNames <- function(...,
-        design = NULL,
-        designPlan = NULL,
-        stageResults = NULL,
-        analysisResults = NULL,
-        dataset = NULL,
-        designCharacteristics = NULL) {
-    .getParameterCaptions(
-        captionList = C_TABLE_COLUMN_NAMES,
-        design = design,
-        designPlan = designPlan,
-        stageResults = stageResults,
-        analysisResults = analysisResults,
-        dataset = dataset,
-        designCharacteristics = designCharacteristics,
-        tableColumns = TRUE
-    )
-}
-
-C_PARAMETER_FORMAT_FUNCTIONS <- list(
+C_PARAMETER_FORMAT_FUNCTIONS <- createDictionary("C_PARAMETER_FORMAT_FUNCTIONS", list(
     means = ".formatMeans",
     stDevs = ".formatStDevs",
     stDev = ".formatStDevs",
@@ -1131,11 +1240,9 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     alphaSpent = ".formatProbabilities",
     alpha0Vec = ".formatProbabilities",
     simAlpha = ".formatProbabilities",
-    criticalValues = ".formatCriticalValuesFisher", # will be set in class TrialDesignFisher
-    criticalValues = ".formatCriticalValues", # will be set in class TrialDesignGroupSequential
+    criticalValues = ".formatCriticalValues",
     betaSpent = ".formatProbabilities",
     futilityBounds = ".formatCriticalValues",
-    alpha0Vec = ".formatProbabilities",
     constantBoundsHP = ".formatCriticalValues",
     nMax = ".formatProbabilities",
     nFixed = ".formatSampleSizes",
@@ -1145,6 +1252,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     inflationFactor = ".formatProbabilities",
     information = ".formatRates",
     power = ".formatProbabilities",
+    sided = ".formatSided",
     rejectionProbabilities = ".formatProbabilities",
     futilityProbabilities = ".formatFutilityProbabilities",
     probs = ".formatProbabilities",
@@ -1176,7 +1284,6 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     overallStDevs2 = ".formatStDevs",
     overallStDevs = ".formatStDevs",
     overallPooledStDevs = ".formatStDevs",
-    testStatistics = ".formatTestStatistics",
     combInverseNormal = ".formatTestStatistics",
     combFisher = ".formatTestStatisticsFisher",
     weightsFisher = ".formatRates",
@@ -1217,6 +1324,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     lambda1 = ".formatRates",
     eventTime = ".formatEventTime",
     accrualTime = ".formatTime",
+    accrualTimeOriginal = ".formatTime",
     totalAccrualTime = ".formatTime",
     remainingTime = ".formatTime",
     followUpTime = ".formatTime",
@@ -1229,7 +1337,6 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     expectedEventsH1 = ".formatEvents",
     analysisTime = ".formatTime",
     studyDurationH1 = ".formatDurations",
-    expectedNumberOfSubjectsH1 = ".formatSampleSizes",
     expectedEvents = ".formatEvents",
     varianceEvents = ".formatEvents",
     overallExpectedEvents = ".formatEvents",
@@ -1238,6 +1345,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     overallEvents = ".formatEvents",
     expectedNumberOfEvents = ".formatEvents",
     expectedNumberOfEventsPerStage = ".formatEvents",
+    cumulativeEventsPerStage = ".formatEvents",
     eventsNotAchieved = ".formatRates",
     subjects = ".formatSampleSizes",
     futilityStop = ".formatProbabilities",
@@ -1254,9 +1362,9 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     accrualIntensity = ".formatAccrualIntensities",
     accrualIntensityRelative = ".formatAccrualIntensities",
     eventsPerStage = ".formatEvents",
-    expectedNumberOfEvents = ".formatEvents",
-    expectedNumberOfSubjects = ".formatEvents",
-    singleNumberOfEventsPerStage = ".formatEvents",
+    singleEventsPerStage = ".formatEvents",
+    singleEventsPerArmAndStage = ".formatEvents",
+    singleEventsPerSubsetAndStage = ".formatEvents",
     time = ".formatTime",
     cumulativeEventProbabilities = ".formatProbabilities",
     eventProbabilities1 = ".formatProbabilities",
@@ -1277,7 +1385,6 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     overallPisControl = ".formatRates",
     overallPisTreatment = ".formatRates",
     adjustedStageWisePValues = ".formatPValues",
-    overallAdjustedTestStatistics = ".formatTestStatisticsFisher", # will be set in class ClosedCombinationTestResults
     overallAdjustedTestStatistics = ".formatTestStatistics",
     conditionalErrorRate = ".formatProbabilities",
     secondStagePValues = ".formatPValues",
@@ -1286,6 +1393,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     effectMatrix = ".formatMeans",
     gED50 = ".formatHowItIs",
     slope = ".formatHowItIs",
+    doseLevels = ".formatHowItIs",
     epsilonValue = ".formatHowItIs",
     threshold = ".formatHowItIs",
     rejectAtLeastOne = ".formatProbabilities",
@@ -1314,5 +1422,16 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
     locationConditionalPower = ".formatProbabilities",
     variationConditionalPower = ".formatProbabilities",
     subscoreConditionalPower = ".formatProbabilities",
-    performanceScore = ".formatProbabilities"
-)
+    performanceScore = ".formatProbabilities",
+    overdispersion = ".formatStDevs",
+    lambda = ".formatRates",
+    fixedExposureTime = ".formatTime",
+    calendarTime = ".formatTime",
+    studyTime = ".formatTime",
+    studySubjects = ".formatSampleSizes",
+    expectedStudyDurationH1 = ".formatTime",
+    informationOverStages = ".formatRatesDynamic",
+    expectedInformationH0 = ".formatRatesDynamic",
+    expectedInformationH01 = ".formatRatesDynamic",
+    expectedInformationH1 = ".formatRatesDynamic"
+))
