@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 8629 $
+## |  Last changed: $Date: 2025-03-24 09:50:39 +0100 (Mo, 24 Mrz 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -53,25 +53,25 @@ NULL
     }
 
     if (.isMultiArmSimulationResults(obj)) {
-        if (type == 1) { # Multi-arm, Overall Success
+        if (type == 1) { 
             return(.addNumberToPlotCaption("Overall Success", type, numberInCaptionEnabled))
-        } else if (type == 2) { # Multi-arm, Success per Stage
+        } else if (type == 2) { 
             return(.addNumberToPlotCaption("Success per Stage", type, numberInCaptionEnabled))
-        } else if (type == 3) { # Multi-arm, Selected Arms per Stage
+        } else if (type == 3) { 
             return(.addNumberToPlotCaption("Selected Arms per Stage", type, numberInCaptionEnabled))
-        } else if (type == 4) { # Multi-arm, Rejected Arms per Stage
+        } else if (type == 4) { 
             return(.addNumberToPlotCaption(ifelse(obj$.design$kMax > 1,
                 "Rejected Arms per Stage", "Rejected Arms"
             ), type, numberInCaptionEnabled))
         }
     } else if (.isEnrichmentSimulationResults(obj)) {
-        if (type == 1) { # Enrichment, Overall Success
+        if (type == 1) { 
             return(.addNumberToPlotCaption("Overall Success", type, numberInCaptionEnabled))
-        } else if (type == 2) { # Enrichment, Success per Stage
+        } else if (type == 2) { 
             return(.addNumberToPlotCaption("Success per Stage", type, numberInCaptionEnabled))
-        } else if (type == 3) { # Enrichment, Selected Populations per Stage
+        } else if (type == 3) { 
             return(.addNumberToPlotCaption("Selected Populations per Stage", type, numberInCaptionEnabled))
-        } else if (type == 4) { # Enrichment, Rejected Populations per Stage
+        } else if (type == 4) { 
             return(.addNumberToPlotCaption(ifelse(obj$.design$kMax > 1,
                 "Rejected Populations per Stage", "Rejected Populations"
             ), type, numberInCaptionEnabled))
@@ -83,7 +83,12 @@ NULL
     if (inherits(obj, "TrialDesignPlan") || inherits(obj, "SimulationResults")) {
         if (type == 5) {
             if (obj$.isSampleSizeObject()) {
-                return(.addNumberToPlotCaption("Sample Size", type, numberInCaptionEnabled))
+                return(.addNumberToPlotCaption(
+                    ifelse(
+                        .isTrialDesignPlanSurvival(obj) || inherits(obj, "SimulationResultsSurvival"),
+                        "Number of Events", 
+                        "Sample Size"
+                    ), type, numberInCaptionEnabled))
             } else {
                 return(.addNumberToPlotCaption(
                     "Overall Power and Early Stopping",
@@ -91,10 +96,12 @@ NULL
                 ))
             }
         } else if (type == 6) {
-            return(.addNumberToPlotCaption(ifelse(.isTrialDesignPlanSurvival(obj) ||
-                inherits(obj, "SimulationResultsSurvival"),
-            "Number of Events", "Sample Size"
-            ), type, numberInCaptionEnabled))
+            return(.addNumberToPlotCaption(
+                ifelse(
+                    .isTrialDesignPlanSurvival(obj) || inherits(obj, "SimulationResultsSurvival"),
+                    "Expected Number of Events and Power / Early Stop", 
+                    "Expected Sample Size and Power / Early Stop"
+                ), type, numberInCaptionEnabled))
         } else if (type == 7) {
             return(.addNumberToPlotCaption("Overall Power", type, numberInCaptionEnabled))
         } else if (type == 8) {
@@ -156,20 +163,7 @@ NULL
 }
 
 .getPlotTypeNumber <- function(type, x) {
-    if (missing(type) || is.null(type) || length(type) == 0 || all(is.na(type))) {
-        stop(C_EXCEPTION_TYPE_MISSING_ARGUMENT, "'type' must be defined")
-    }
-
-    if (!is.numeric(type) && !is.character(type)) {
-        stop(
-            C_EXCEPTION_TYPE_MISSING_ARGUMENT,
-            "'type' must be an integer or character value or vector (is ", .getClassName(type), ")"
-        )
-    }
-
-    if (is.numeric(type)) {
-        .assertIsIntegerVector(type, "type", naAllowed = FALSE, validateType = FALSE)
-    }
+    .assertIsValidPlotType(type, naAllowed = FALSE)
 
     if (is.character(type)) {
         if (length(type) == 1 && type == "all") {
@@ -234,6 +228,7 @@ NULL
         for (p in plotList) {
             suppressMessages(print(p))
         }
+        
         return(invisible(plotList))
     }
 
@@ -372,17 +367,19 @@ plotTypes <- function(obj, output = c("numeric", "caption", "numcap", "capnum"),
 #'   \item \code{capnum}:  list with caption and number
 #' }
 #'
-#' @return Returns a list if \code{option} is either \code{capnum} or {numcap}
+#' @return Returns a list if \code{option} is either \code{capnum} or \code{numcap}
 #' or returns a vector that is of  character type for \code{option=caption} or
 #' of numeric type for \code{option=numeric}.
 #'
 #' @examples
+#' \dontrun{
 #' design <- getDesignInverseNormal(kMax = 2)
 #' getAvailablePlotTypes(design, "numeric")
 #' plotTypes(design, "caption")
 #' getAvailablePlotTypes(design, "numcap")
 #' plotTypes(design, "capnum")
-#'
+#' }
+#' 
 #' @export
 #'
 getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap", "capnum"),
@@ -401,15 +398,31 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     types <- integer(0)
     if (inherits(obj, "TrialDesignPlan")) {
         if (obj$.design$kMax > 1) {
-            types <- c(types, 1:4)
+            types <- c(types, 1)
+            if (!.isTrialDesignPlanCountData(obj)) {
+                types <- c(types, 2)
+            }
+            types <- c(types, 3:4)
         }
-        types <- c(types, 5)
         if (obj$.isSampleSizeObject()) {
+            if (!.isTrialDesignPlanCountData(obj) || length(obj[["theta"]]) > 1) {
+                types <- c(types, 5)
+            }
             if (.isTrialDesignPlanSurvival(obj)) {
                 types <- c(types, 13, 14)
             }
         } else {
-            types <- c(types, 6:9)
+            if (obj$.design$kMax > 1) {
+                types <- c(types, 5, 6)
+            }
+            types <- c(types, 7)
+            if (obj$.design$kMax > 1) {
+                types <- c(types, 8)
+                if (!.isTrialDesignPlanCountData(obj) ||
+                        obj$isGeneratedParameter("expectedNumberOfSubjectsH1")) {
+                    types <- c(types, 9)
+                }
+            }
             if (.isTrialDesignPlanSurvival(obj)) {
                 types <- c(types, 10:14)
             }
@@ -437,13 +450,16 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         }
         types <- c(types, 4)
         if (!grepl("MultiArm", .getClassName(obj)) || obj$.design$kMax > 1) {
-            types <- c(types, 5:6)
+            types <- c(types, 5)
+            if (!grepl("CountData", .getClassName(obj))) {
+                types <- c(types, 6)
+            }
         }
         types <- c(types, 7)
         if (obj$.design$kMax > 1) {
             types <- c(types, 8)
         }
-        if (!grepl("MultiArm", .getClassName(obj)) || obj$.design$kMax > 1) {
+        if (!grepl("(MultiArm|CountData)", .getClassName(obj)) || obj$.design$kMax > 1) {
             types <- c(types, 9)
         }
         if (inherits(obj, "SimulationResultsSurvival")) {
@@ -482,7 +498,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     }
 
     if (output == "caption") {
-        captions <- character(0)
+        captions <- character()
         for (type in types) {
             captions <- c(captions, .getPlotCaption(obj,
                 type = type,
@@ -514,6 +530,10 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 }
 
 .getVariedParameterHint <- function(variedParameter, variedParameterName) {
+    if (length(variedParameter) != 2) {
+        return("")
+    }
+
     return(paste0(
         "Note: interim values between ", round(variedParameter[1], 4), " and ",
         round(variedParameter[2], 4), " were calculated to get smoother lines; use, e.g., '",
@@ -523,8 +543,9 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 }
 
 .getRexepSaveCharacter <- function(x) {
-    x <- gsub("\\$", "\\\\$", x)
-    x <- gsub("\\.", "\\\\.", x)
+    for (s in c("$", ".", "{", "}", "(", ")", "[", "]", "+", "-", "*", "/", "^", "?", "|")) {
+        x <- gsub(paste0("\\", s), paste0("\\\\", s), x)
+    }
     return(x)
 }
 
@@ -545,15 +566,26 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     if (grepl("^rpact::", parameterName)) {
         return(parameterName)
     }
+    
+    if (grepl("^function", objectName) || nchar(objectName) > 40) {
+        objectName <- "x"
+    }
 
     return(paste0(objectName, "$", parameterName))
 }
 
-.showPlotSourceInformation <- function(objectName, ...,
-        xParameterName, yParameterNames,
-        hint = NA_character_, nMax = NA_integer_, type = NA_integer_,
-        showSource = FALSE, xValues = NA_real_,
+.showPlotSourceInformation <- function(
+        objectName, 
+        ...,
+        xParameterName, 
+        yParameterNames,
+        hint = NA_character_, 
+        nMax = NA_integer_, 
+        type = NA_integer_,
+        showSource = FALSE, 
+        xValues = NA_real_,
         lineType = TRUE) {
+        
     if (is.character(showSource)) {
         if (length(showSource) != 1 || trimws(showSource) == "") {
             return(invisible(NULL))
@@ -583,6 +615,11 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         type, ")"
     ), ""), ":\n", sep = "")
 
+    if (grepl("^function", xParameterName) || nchar(xParameterName) > 40 ||
+            any(grepl("^function", yParameterNames)) || any(nchar(yParameterNames) > 40)) {
+        return(invisible(NULL))
+    }
+    
     xAxisCmd <- .reconstructSequenceCommand(xValues)
     if (is.na(xAxisCmd)) {
         if (!grepl("(\\$)|(^c\\()", xParameterName) || grepl("^\\.design", xParameterName)) {
@@ -613,7 +650,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         )
     }
 
-    yAxisCmds <- c()
+    yAxisCmds <- character()
     if (length(yParameterNames) == 1) {
         yAxisCmds <- .createValidParameterName(objectName, yParameterNames)
     } else {
@@ -625,7 +662,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         cat("  y-axis: ", yAxisCmds, "\n", sep = "")
     } else {
         cat("  y-axes:\n")
-        for (i in 1:length(yAxisCmds)) {
+        for (i in seq_len(length(yAxisCmds))) {
             cat("    y", i, ": ", yAxisCmds[i], "\n", sep = "")
         }
     }
@@ -700,8 +737,8 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         addPowerAndAverageSampleNumber = FALSE,
         theta = seq(-1, 1, 0.02),
         nMax = NA_integer_,
-        mandatoryParameterNames = character(0),
-        yParameterNames = character(0)) {
+        mandatoryParameterNames = character(),
+        yParameterNames = character()) {
     if (.isTrialDesignSet(parameterSet) && parameterSet$getSize() > 1 &&
             (is.null(parameterSet$variedParameters) || length(parameterSet$variedParameters) == 0)) {
         stop(
@@ -711,11 +748,13 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     }
 
     if (inherits(parameterSet, "TrialDesignSet")) {
-        suppressWarnings(data <- as.data.frame(parameterSet,
+        suppressWarnings(data <- as.data.frame(
+            parameterSet,
             niceColumnNamesEnabled = FALSE,
             includeAllParameters = TRUE,
             addPowerAndAverageSampleNumber = addPowerAndAverageSampleNumber,
-            theta = theta, nMax = nMax
+            theta = theta,
+            nMax = nMax
         ))
     } else {
         parameterNames <- parameterSet$.getVisibleFieldNamesOrdered()
@@ -727,7 +766,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             mandatoryParameterNames = mandatoryParameterNames
         ))
     }
-
+    
     if (!.isTrialDesignSet(parameterSet)) {
         variedParameters <- logical(0)
         if ("stages" %in% colnames(data)) {
@@ -770,26 +809,28 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     for (variedParameter in variedParameters) {
         variedParameterNames <- c(
             variedParameterNames,
-            .getTableColumnNames(design = designMaster)[[variedParameter]]
+            .getParameterCaption(variedParameter, designMaster, tableOutputEnabled = TRUE)
         )
     }
     names(variedParameters) <- variedParameterNames
     return(list(data = data, variedParameters = variedParameters))
 }
 
-.getCategories <- function(data, yParameterName, tableColumnNames) {
+.getCategories <- function(data, yParameterName, parameterSet) {
+    axisLabel <- .getAxisLabel(yParameterName, parameterSet)
     if (is.null(data$categories) || sum(is.na(data$categories)) > 0) {
-        return(rep(.getAxisLabel(yParameterName, tableColumnNames), nrow(data)))
+        return(rep(axisLabel, nrow(data)))
     }
 
-    return(paste(data$categories, .getAxisLabel(yParameterName, tableColumnNames), sep = ", "))
+    return(paste(data$categories, axisLabel, sep = ", "))
 }
 
-.getAxisLabel <- function(parameterName, tableColumnNames) {
-    axisLabel <- tableColumnNames[[parameterName]]
+.getAxisLabel <- function(parameterName, parameterSet) {
+    axisLabel <- .getParameterCaption(parameterName, parameterSet, tableOutputEnabled = TRUE)
     if (is.null(axisLabel)) {
         return(paste0("%", parameterName, "%"))
     }
+    axisLabel <- gsub(" \\(one-sided P-value Scale\\)$", "", axisLabel, ignore.case = TRUE)
     return(axisLabel)
 }
 
@@ -811,14 +852,26 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     return(TRUE)
 }
 
-.plotParameterSet <- function(..., parameterSet, designMaster, xParameterName, yParameterNames,
-        mainTitle = NA_character_, xlab = NA_character_, ylab = NA_character_,
-        palette = "Set1", theta = seq(-1, 1, 0.02), nMax = NA_integer_,
-        plotPointsEnabled = NA, legendPosition = NA_integer_,
+.plotParameterSet <- function(
+        ..., 
+        parameterSet, 
+        designMaster, 
+        xParameterName, 
+        yParameterNames,
+        mainTitle = NA_character_, 
+        xlab = NA_character_, 
+        ylab = NA_character_,
+        palette = "Set1", 
+        theta = seq(-1, 1, 0.02), 
+        nMax = NA_integer_,
+        plotPointsEnabled = NA, 
+        legendPosition = NA_integer_,
         variedParameters = logical(0),
         qnormAlphaLineEnabled = TRUE,
         yAxisScalingEnabled = TRUE,
-        ratioEnabled = NA, plotSettings = NULL) {
+        ratioEnabled = NA, 
+        plotSettings = NULL) {
+        
     simulationEnrichmentEnmabled <- grepl("SimulationResultsEnrichment", .getClassName(parameterSet))
     if (.isParameterSet(parameterSet) || .isTrialDesignSet(parameterSet)) {
         parameterNames <- c(xParameterName, yParameterNames)
@@ -827,8 +880,8 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             "overallEarlyStop", "calculatedPower"
         ))]
         fieldNames <- c(
-            names(parameterSet$getRefClass()$fields()),
-            names(designMaster$getRefClass()$fields())
+            names(parameterSet), 
+            names(designMaster) 
         )
         if (simulationEnrichmentEnmabled) {
             fieldNames <- c(fieldNames, gsub("s$", "", names(parameterSet$effectList)), "situation")
@@ -847,7 +900,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         }
     } else {
         if (is.null(plotSettings) || !inherits(plotSettings, "PlotSettings")) {
-            plotSettings <- PlotSettings()
+            plotSettings <- PlotSettings$new()
         }
     }
 
@@ -884,7 +937,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             yParameterNames = yParameterNames
         )
         data <- df$data
-
+        
         variedParameters <- df$variedParameters
         variedParameters <- na.omit(variedParameters)
         variedParameters <- variedParameters[variedParameters != "NA"]
@@ -903,7 +956,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             "or an object that inherits from 'ParameterSet'"
         )
     }
-
+    
     if (length(variedParameters) > 0) {
         legendTitle <- .firstCharacterToUpperCase(paste(names(variedParameters), collapse = "\n"))
         categoryParameterName <- variedParameters[1]
@@ -912,6 +965,19 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         categoryParameterName <- NA_character_
     }
 
+    tryCatch({
+        if (all(c("criticalValuesPValueScale", "futilityBoundsPValueScale") %in% yParameterNames)) {
+            index <- nrow(data)
+            if ("stages" %in% colnames(data)) {
+                index <- which(data$stages == max(data$stages))
+            }
+            data$futilityBoundsPValueScale[index] <- data$criticalValuesPValueScale[index]
+            data <- unique(data[, c(xParameterName, yParameterNames)])
+        }
+    }, error = function(e) {
+        .logError("Failed to set last 'futilityBoundsPValueScale' value: ", e$message)
+    })
+
     yParameterName1 <- yParameterNames[1]
     yParameterName2 <- NULL
     yParameterName3 <- NULL
@@ -921,56 +987,54 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     if (length(yParameterNames) >= 3) {
         yParameterName3 <- yParameterNames[3]
     }
-
+    
     mirrorModeEnabled <- any(grepl("Mirrored$", yParameterNames))
-
-    tableColumnNames <- .getTableColumnNames(design = designMaster)
-
-    xAxisLabel <- .getAxisLabel(xParameterName, tableColumnNames)
-    yAxisLabel1 <- .getAxisLabel(yParameterName1, tableColumnNames)
+    xAxisLabel <- .getAxisLabel(xParameterName, parameterSet)
+    yAxisLabel1 <- .getAxisLabel(yParameterName1, parameterSet)
     yAxisLabel2 <- NULL
     if (!is.null(yParameterName2) && !is.null(yParameterName3)) {
         if (!is.na(yParameterName2)) {
-            pn2 <- .getAxisLabel(yParameterName2, tableColumnNames)
+            pn2 <- .getAxisLabel(yParameterName2, parameterSet)
             if (yParameterName2 == "overallEarlyStop") {
                 pn2 <- "Stopping Probability"
             }
-            yAxisLabel2 <- paste(pn2, .getAxisLabel(yParameterName3, tableColumnNames), sep = " and ")
+            yAxisLabel2 <- paste(pn2, .getAxisLabel(yParameterName3, parameterSet), sep = " and ")
         } else {
-            yAxisLabel2 <- .getAxisLabel(yParameterName3, tableColumnNames)
+            yAxisLabel2 <- .getAxisLabel(yParameterName3, parameterSet)
         }
     } else if (xParameterName == "effectMatrix" && !is.null(yParameterName2) && !is.na(yParameterName2) &&
             yParameterName1 %in% c("expectedNumberOfEvents", "expectedNumberOfSubjects") &&
             yParameterName2 == "rejectAtLeastOne") {
         # special case: simulation results, plot type 6 (expected number of subjects and power)
-        yAxisLabel2 <- .getAxisLabel(yParameterName2, tableColumnNames)
+        yAxisLabel2 <- .getAxisLabel(yParameterName2, parameterSet)
         yParameterName3 <- yParameterName2
         yParameterName2 <- NA_character_
     } else if (!is.null(yParameterName2) && !mirrorModeEnabled) {
-        yAxisLabel1 <- paste(yAxisLabel1, .getAxisLabel(yParameterName2, tableColumnNames), sep = " and ")
+        yAxisLabel1 <- paste(yAxisLabel1, .getAxisLabel(yParameterName2, parameterSet), sep = " and ")
     }
     if (yParameterName1 %in% c("alphaSpent", "betaSpent")) {
         yAxisLabel1 <- "Cumulative Error"
         if (is.null(yParameterName2)) {
-            yAxisLabel1 <- paste0(yAxisLabel1, " (", .getAxisLabel(yParameterName1, tableColumnNames), ")")
+            yAxisLabel1 <- paste0(yAxisLabel1, " (", .getAxisLabel(yParameterName1, parameterSet), ")")
         }
     }
 
-    yAxisLabel1 <- sub(paste0(C_PARAMETER_NAMES[["futilityBoundsDelayedInformation"]], " and"),
+    yAxisLabel1 <- sub(paste0(.getParameterCaption("futilityBoundsDelayedInformation"), " and"),
         "Lower and", yAxisLabel1,
         fixed = TRUE
     )
-    yAxisLabel1 <- sub(paste0(C_PARAMETER_NAMES[["futilityBoundsDelayedInformationNonBinding"]], " and"),
+    yAxisLabel1 <- sub(paste0(.getParameterCaption("futilityBoundsDelayedInformationNonBinding"), " and"),
         "Lower and", yAxisLabel1,
         fixed = TRUE
     )
-
+    
     if (!("xValues" %in% colnames(data)) || !("yValues" %in% colnames(data))) {
         if (!(xParameterName %in% colnames(data))) {
-            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(xParameterName), " is not available in dataset")
+            print(colnames(data))
+            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(xParameterName), " is not available in dataset (x-axis)")
         }
         if (!(yParameterName1 %in% colnames(data))) {
-            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName1), " is not available in dataset")
+            stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName1), " is not available in dataset (y-axis)")
         }
 
         data$xValues <- data[[xParameterName]]
@@ -986,7 +1050,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             data$yValues2 <- rep(NA_real_, nrow(data))
         } else {
             if (!(yParameterName2 %in% colnames(data))) {
-                stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName2), " is not available in dataset")
+                stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName2), " is not available in dataset (y-axis 2)")
             }
             data$yValues2 <- data[[yParameterName2]]
         }
@@ -994,7 +1058,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             data$yValues3 <- rep(NA_real_, nrow(data))
         } else {
             if (!(yParameterName3 %in% colnames(data))) {
-                stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName3), " is not available in dataset")
+                stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, sQuote(yParameterName3), " is not available in dataset (y-axis 3)")
             }
             data$yValues3 <- data[[yParameterName3]]
         }
@@ -1011,7 +1075,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             data$categories <- rep(NA_character_, nrow(data))
         }
     }
-
+    
     if (!is.na(nMax) && is.null(yParameterName3) && xParameterName == "informationRates") {
         xAxisLabel <- "Sample Size"
         data$xValues <- data$xValues * nMax
@@ -1036,11 +1100,11 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             categories = uc
         ), data)
     }
-
+    
     scalingFactor1 <- 1
     scalingFactor2 <- 1
-    if (!is.null(yParameterName2) && "yValues2" %in% colnames(data) && "yValues3" %in% colnames(data)) {
-        if (yAxisScalingEnabled && !is.null(yParameterName3)) {
+    if (!is.null(yParameterName2) && "yValues2" %in% colnames(data)) {
+        if (yAxisScalingEnabled && !is.null(yParameterName3) && "yValues3" %in% colnames(data)) {
             if (is.na(yParameterName2)) {
                 scalingFactors <- .getScalingFactors(data$yValues, data$yValues3)
             } else {
@@ -1052,20 +1116,20 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         df1 <- data.frame(
             xValues = data$xValues,
             yValues = data$yValues * scalingFactor1,
-            categories = .getCategories(data, yParameterName1, tableColumnNames)
+            categories = .getCategories(data, yParameterName1, parameterSet)
         )
         if (!is.na(yParameterName2)) {
             df2 <- data.frame(
                 xValues = data$xValues,
                 yValues = data$yValues2 * scalingFactor2,
-                categories = .getCategories(data, yParameterName2, tableColumnNames)
+                categories = .getCategories(data, yParameterName2, parameterSet)
             )
         }
-        if (!is.null(yParameterName3)) {
+        if (!is.null(yParameterName3) && "yValues3" %in% colnames(data)) {
             df3 <- data.frame(
                 xValues = data$xValues,
                 yValues = data$yValues3 * scalingFactor2,
-                categories = .getCategories(data, yParameterName3, tableColumnNames)
+                categories = .getCategories(data, yParameterName3, parameterSet)
             )
             if (is.na(yParameterName2)) {
                 data <- rbind(df1, df3)
@@ -1079,6 +1143,11 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         # sort categories for pairwise printing of the legend
         unqiueValues <- unique(as.character(data$categories))
         decreasing <- addPowerAndAverageSampleNumber && xParameterName %in% c("effect", "effectMatrix")
+        
+        if (all(c("criticalValuesPValueScale", "futilityBoundsPValueScale") %in% yParameterNames)) {
+            decreasing <- TRUE
+        }
+        
         catLevels <- unqiueValues[order(unqiueValues, decreasing = decreasing)]
         data$categories <- factor(data$categories, levels = catLevels)
         if (!is.na(legendTitle) && yParameterName1 == "alphaSpent" && yParameterName2 == "betaSpent") {
@@ -1086,7 +1155,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             legendTitle <- paste(legendTitle, "Type of error", sep = sep)
         }
     }
-
+    
     if (is.na(legendPosition)) {
         legendPosition <- .getLegendPosition(
             plotSettings, designMaster, data, yParameterName1,
@@ -1101,16 +1170,31 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     }
 
     plotDashedHorizontalLine <- "criticalValuesEffectScale" %in% yParameterNames && designMaster$sided == 2
-    p <- .plotDataFrame(data,
-        mainTitle = mainTitle, xlab = xlab, ylab = ylab,
-        xAxisLabel = xAxisLabel, yAxisLabel1 = yAxisLabel1, yAxisLabel2 = yAxisLabel2,
-        palette = palette, plotPointsEnabled = plotPointsEnabled, legendTitle = legendTitle,
-        legendPosition = legendPosition, scalingFactor1 = scalingFactor1, scalingFactor2 = scalingFactor2,
+    
+    p <- .plotDataFrame(
+        data,
+        mainTitle = mainTitle, 
+        xlab = xlab, 
+        ylab = ylab,
+        xAxisLabel = xAxisLabel, 
+        yAxisLabel1 = yAxisLabel1, 
+        yAxisLabel2 = yAxisLabel2,
+        palette = palette, 
+        plotPointsEnabled = plotPointsEnabled, 
+        legendTitle = legendTitle,
+        legendPosition = legendPosition, 
+        scalingFactor1 = scalingFactor1, 
+        scalingFactor2 = scalingFactor2,
         addPowerAndAverageSampleNumber = addPowerAndAverageSampleNumber,
-        mirrorModeEnabled = mirrorModeEnabled, plotDashedHorizontalLine = plotDashedHorizontalLine,
-        ratioEnabled = ratioEnabled, plotSettings = plotSettings, sided = designMaster$sided, ...
+        mirrorModeEnabled = mirrorModeEnabled, 
+        plotDashedHorizontalLine = plotDashedHorizontalLine,
+        ratioEnabled = ratioEnabled, 
+        plotSettings = plotSettings, 
+        sided = designMaster$sided, 
+        directionUpper = designMaster$directionUpper, 
+        ...
     )
-
+    
     if (xParameterName == "informationRates") {
         p <- p + ggplot2::scale_x_continuous(breaks = c(0, round(data$xValues, 3)))
     } else if (xParameterName == "situation") { # simulation enrichment
@@ -1155,7 +1239,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     }
 
     if (!.isTrialDesignFisher(designMaster) &&
-            (xParameterName == "informationRates" || xParameterName == "eventsPerStage") &&
+            (xParameterName == "informationRates" || xParameterName == "cumulativeEventsPerStage") &&
             yParameterName1 == "stageLevels") {
         yValue <- designMaster$alpha
         if (designMaster$sided == 2) {
@@ -1223,19 +1307,36 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     return(list(scalingFactor1 = scalingFactor1, scalingFactor2 = scalingFactor2))
 }
 
-.plotDataFrame <- function(data, ..., mainTitle = NA_character_,
-        xlab = NA_character_, ylab = NA_character_, xAxisLabel = NA_character_,
-        yAxisLabel1 = NA_character_, yAxisLabel2 = NA_character_,
-        palette = "Set1", plotPointsEnabled = NA, legendTitle = NA_character_,
-        legendPosition = NA_integer_, scalingFactor1 = 1, scalingFactor2 = 1,
-        addPowerAndAverageSampleNumber = FALSE, mirrorModeEnabled = FALSE, plotDashedHorizontalLine = FALSE,
-        ratioEnabled = FALSE, plotSettings = NULL, sided = 1, discreteXAxis = FALSE) {
+.plotDataFrame <- function(
+        data, 
+        ..., 
+        mainTitle = NA_character_,
+        xlab = NA_character_, 
+        ylab = NA_character_, 
+        xAxisLabel = NA_character_,
+        yAxisLabel1 = NA_character_, 
+        yAxisLabel2 = NA_character_,
+        palette = "Set1", 
+        plotPointsEnabled = NA, 
+        legendTitle = NA_character_,
+        legendPosition = NA_integer_, 
+        scalingFactor1 = 1, 
+        scalingFactor2 = 1,
+        addPowerAndAverageSampleNumber = FALSE, 
+        mirrorModeEnabled = FALSE, 
+        plotDashedHorizontalLine = FALSE,
+        ratioEnabled = FALSE, 
+        plotSettings = NULL, 
+        sided = 1, 
+        discreteXAxis = FALSE,
+        directionUpper = NA) {
+        
     if (!is.data.frame(data)) {
         stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, "'data' must be a data.frame (is ", .getClassName(data), ")")
     }
 
     if (is.null(plotSettings)) {
-        plotSettings <- PlotSettings()
+        plotSettings <- PlotSettings$new()
     }
 
     nRow <- nrow(data)
@@ -1252,7 +1353,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
             removedRows1, removedRows2
         ), call. = FALSE)
     }
-
+    
     categoryEnabled <- !is.null(data[["categories"]]) && !all(is.na(data$categories))
     groupEnabled <- !is.null(data[["groups"]]) && !all(is.na(data$groups))
     if (categoryEnabled && groupEnabled) {
@@ -1267,7 +1368,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 
     data$yValues[!is.na(data$yValues) & is.infinite(data$yValues)] <- NA_real_
     data <- data[!is.na(data$yValues), ]
-
+    
     if (categoryEnabled && groupEnabled) {
         p <- ggplot2::ggplot(data, ggplot2::aes(
             x = .data[["xValues"]], y = .data[["yValues"]],
@@ -1287,14 +1388,14 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     } else {
         p <- ggplot2::ggplot(data, ggplot2::aes(x = .data[["xValues"]], y = .data[["yValues"]]))
     }
-
+    
     p <- plotSettings$setTheme(p)
     p <- plotSettings$hideGridLines(p)
 
     if (discreteXAxis) {
         p <- p + ggplot2::scale_x_continuous(breaks = round(data$xValues))
     }
-
+    
     # set main title
     p <- plotSettings$setMainTitle(p, mainTitle)
 
@@ -1307,22 +1408,32 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         p <- plotSettings$setLegendTitle(p, legendTitle)
         p <- plotSettings$setLegendLabelSize(p)
     }
-
+    
     # set optional scale limits
     xLim <- .getOptionalArgument("xlim", ...)
     yLim <- .getOptionalArgument("ylim", ...)
     if (is.null(yLim) && !missing(yAxisLabel1) &&
             !is.na(yAxisLabel1) && yAxisLabel1 == "Critical value") {
-        yMax <- max(na.omit(data$yValues))
-        if (length(yMax) == 1 && yMax < 0.1) {
-            yLim <- c(0, 2 * yMax)
+        yMax <- .applyDirectionOfAlternative(na.omit(data$yValues), 
+            directionUpper, type = "maxMin", phase = "design")
+        if (length(yMax) == 1) {
+            if (yMax > 0 && yMax < 0.1) {
+                yLim <- c(0, 2 * yMax)
+            }
+            else if (yMax < 0 && yMax > -0.1) {
+                yLim <- c(0, 2 * yMax)
+            }
         }
     }
+    
     if ((!is.null(xLim) && is.numeric(xLim) && length(xLim) == 2) ||
             (!is.null(yLim) && is.numeric(yLim) && length(yLim) == 2)) {
         p <- p + ggplot2::coord_cartesian(
-            xlim = xLim, ylim = yLim, expand = TRUE,
-            default = FALSE, clip = "on"
+            xlim = sort(xLim), 
+            ylim = sort(yLim), 
+            expand = TRUE,
+            default = FALSE, 
+            clip = "on"
         )
     }
 
@@ -1336,8 +1447,13 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     yAxisLabel2 <- .toCapitalized(yAxisLabel2)
 
     p <- plotSettings$setAxesLabels(p,
-        xAxisLabel = xAxisLabel, yAxisLabel1 = yAxisLabel1, yAxisLabel2 = yAxisLabel2,
-        xlab = xlab, ylab = ylab, scalingFactor1 = scalingFactor1, scalingFactor2 = scalingFactor2
+        xAxisLabel = xAxisLabel, 
+        yAxisLabel1 = yAxisLabel1, 
+        yAxisLabel2 = yAxisLabel2,
+        xlab = xlab, 
+        ylab = ylab, 
+        scalingFactor1 = scalingFactor1, 
+        scalingFactor2 = scalingFactor2
     )
 
     # plot lines and points
@@ -1386,8 +1502,14 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     return(pointBorder)
 }
 
-.getLegendPosition <- function(plotSettings, designMaster, data, yParameterName1,
-        yParameterName2, addPowerAndAverageSampleNumber) {
+.getLegendPosition <- function(
+        plotSettings, 
+        designMaster, 
+        data, 
+        yParameterName1,
+        yParameterName2, 
+        addPowerAndAverageSampleNumber) {
+        
     if (length(unique(data$categories)) > 6) {
         plotSettings$adjustPointSize(0.8)
         plotSettings$adjustLegendFontSize(0.8)
@@ -1424,8 +1546,10 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
     if (designMaster$sided == 2) {
         alpha <- alpha / 2
     }
-    yValue <- .getOneMinusQNorm(alpha)
-    yValueLabel <- paste0("qnorm(1 - ", alpha, " ) == ", round(yValue, 4))
+    yValue <- .applyDirectionOfAlternative(.getOneMinusQNorm(alpha), 
+        designMaster$directionUpper, type = "negateIfLower", phase = "design")
+    prefix <- ifelse(isFALSE(designMaster$directionUpper), "-", "")
+    yValueLabel <- paste0(prefix, "qnorm(1 - ", alpha, " ) == ", round(yValue, 4))
     if (designMaster$sided == 1) {
         p <- p + ggplot2::geom_hline(yintercept = yValue, linetype = "dashed")
     } else {
@@ -1445,9 +1569,12 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
 
     # expand y-axis range
     if (designMaster$sided == 1) {
-        yMax <- max(stats::na.omit(data$yValues))
+        yMax <- .applyDirectionOfAlternative(na.omit(data$yValues), 
+            designMaster$directionUpper, type = "maxMin", phase = "design")
         if (!is.null(data$yValues2) && length(data$yValues2) > 0) {
-            yMax <- max(yMax, stats::na.omit(data$yValues2))
+            yMax <- .applyDirectionOfAlternative(c(yMax, 
+                stats::na.omit(data$yValues2)), 
+                designMaster$directionUpper, type = "maxMin", phase = "design")
         }
         eps <- (yMax - yValue) * 0.15
 
@@ -1462,7 +1589,7 @@ getAvailablePlotTypes <- function(obj, output = c("numeric", "caption", "numcap"
         return(lambda2[1])
     }
 
-    for (i in 1:length(piecewiseSurvivalTime)) {
+    for (i in seq_len(length(piecewiseSurvivalTime))) {
         if (time <= piecewiseSurvivalTime[i]) {
             return(lambda2[i])
         }
@@ -1592,7 +1719,7 @@ saveLastPlot <- function(filename, outputPath = .getRelativeFigureOutputPath())
 
     plotSettings <- x$.plotSettings
     if (is.null(plotSettings)) {
-        plotSettings <- PlotSettings()
+        plotSettings <- PlotSettings$new()
     } else {
         plotSettings <- plotSettings$clone()
     }
@@ -1604,11 +1731,11 @@ saveLastPlot <- function(filename, outputPath = .getRelativeFigureOutputPath())
 
 .getGridLegendPosition <- function(legendPosition, typeNumbers, grid) {
     if (length(typeNumbers) <= 3 || grid <= 1) {
-        return(NA_integer_)
+        return(legendPosition)
     }
 
     if (is.na(legendPosition)) {
-        return(-1L) # hide legend
+        return(-1L) # hide legend for more than 3 plots
     }
 
     return(legendPosition)
@@ -1637,3 +1764,33 @@ saveLastPlot <- function(filename, outputPath = .getRelativeFigureOutputPath())
 
     return(.arrayToString(round(value, 2)))
 }
+
+.showWarningIfPlotArgumentWillBeIgnored <- function(type, ..., obj = NULL) {
+    if ((is.null(type) || all(is.na(type)) || any(type == "all", na.rm = TRUE)) && 
+            (is.null(obj) || inherits(obj, "TrialDesignPlan"))) {
+        return(invisible())
+    }
+    
+    showFutilityBounds <- .getOptionalArgument("showFutilityBounds", ...)
+    if ((all(type != 3, na.rm = TRUE) || (!is.null(obj) && !inherits(obj, "TrialDesignPlan"))) && !is.null(showFutilityBounds)) {
+        objTypeInfo <- ifelse(!is.null(obj) && !inherits(obj, "TrialDesignPlan"), " design plan", "")
+        warning("Argument 'showFutilityBounds' (", showFutilityBounds, ") is only available for", objTypeInfo, " plot type 3; ",
+            "it will be ignored", call. = FALSE)
+    }
+    
+    showAlphaSpent <- .getOptionalArgument("showAlphaSpent", ...)
+    showBetaSpent <- .getOptionalArgument("showBetaSpent", ...)
+    if (all(type != 4, na.rm = TRUE) && all(type != "all", na.rm = TRUE) && 
+            (!is.null(showAlphaSpent) || !is.null(showBetaSpent))) {
+        if (!is.null(showAlphaSpent) && !is.null(showBetaSpent)) {
+            warning("Arguments 'showAlphaSpent' (", showAlphaSpent, ") and 'showBetaSpent' (", showBetaSpent, ") ",
+                "are only available for plot type 4; they will be ignored", call. = FALSE)
+        } else if (!is.null(showAlphaSpent)) {
+            warning("Argument 'showAlphaSpent' (", showAlphaSpent, ") is only available for plot type 4; ",
+                "it will be ignored", call. = FALSE)
+        } else {
+            warning("Argument 'showBetaSpent' (", showBetaSpent, ") is only available for plot type 4; ",
+                "it will be ignored", call. = FALSE)
+        }
+    }
+}
