@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8276 $
-## |  Last changed: $Date: 2024-09-26 13:37:54 +0200 (Do, 26 Sep 2024) $
+## |  File version: $Revision: 8624 $
+## |  Last changed: $Date: 2025-03-21 13:24:59 +0100 (Fr, 21 Mrz 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -39,6 +39,14 @@ NULL
 }
 
 .toCapitalized <- function(x, ignoreBlackList = FALSE) {
+    result <- character()
+    for (s in x) {
+        result <- c(result, .toCapitalizedSingleCharacter(s, ignoreBlackList = ignoreBlackList))
+    }
+    return(result)
+}
+
+.toCapitalizedSingleCharacter <- function(x, ignoreBlackList = FALSE) {
     if (is.null(x) || is.na(x) || !is.character(x)) {
         return(x)
     }
@@ -102,10 +110,15 @@ NULL
 }
 
 .firstCharacterToUpperCase <- function(x, ..., sep = "") {
+    if (is.null(x) || length(x) == 0) {
+        return(x)
+    }
+    
     args <- list(...)
     if (length(args) > 0) {
-        x <- paste(x, unlist(args, use.names = FALSE), collapse = sep, sep = sep)
+        x <- paste(c(x, unlist(args, use.names = FALSE)), collapse = sep, sep = sep)
     }
+    x <- as.character(x)
     substr(x, 1, 1) <- toupper(substr(x, 1, 1))
     return(x)
 }
@@ -1589,8 +1602,44 @@ getParameterName <- function(obj, parameterCaption) {
     parameterSet$.deprecatedFieldNames <- unique(c(parameterSet$.deprecatedFieldNames, fieldName))
 }
 
+.getPipeOperatorQueue <- function(x) {
+    queue <- attr(x, "queue")
+    if (is.null(queue)) {
+        queue <- list()
+    }
+    if (!is.null(x[["object"]])) {
+        objectQueue <- attr(x$object, "queue")
+        if (!is.null(objectQueue)) {
+            queue <- c(queue, objectQueue)
+        }
+    }
+    return(queue)
+}
+
+.addObjectToPipeOperatorQueue <- function(x) {
+    if (inherits(x, "SummaryFactory")) {
+        x <- x$object
+    }
+    
+    queue <- .getPipeOperatorQueue(x)
+    queue[[length(queue) + 1]] <- x
+    attr(x, "markdown") <- TRUE
+    attr(x, "queue") <- queue
+    return(x)
+}
+
 .resetPipeOperatorQueue <- function(x) {
-    attr(x, "queue") <- NULL
+    for (attrName in c("queue", "printObject", "printObjectSeparator", "markdown")) {
+        tryCatch({
+            if (inherits(x, "SummaryFactory")) {
+                attr(x$object, attrName) <- NULL
+            } else {
+                attr(x, attrName) <- NULL
+            }
+        }, error = function(e) {
+            message("Failed to reset pipe operator queue attribute ", sQuote(attrName), ": ", e$message)
+        })
+    }
     return(x)
 }
 
@@ -1726,3 +1775,170 @@ getParameterName <- function(obj, parameterCaption) {
 
     return(value)
 }
+
+#' 
+#' @note This is only needed such that we can mock the function in the tests.
+#' 
+#' @keywords internal
+#' 
+#' @noRd 
+#' 
+.isPackageNamespaceLoaded <- function(package, ..., quietly = FALSE) {
+    base::requireNamespace(package, quietly = quietly, ...)
+}
+
+#' 
+#' @title
+#' Save Options
+#'
+#' @description
+#' Saves the current `rpact` options to a configuration file.
+#'
+#' @details
+#' This function attempts to save the current `rpact` options to a configuration file
+#' located in the user's configuration directory. If the `rappdirs` package is not installed,
+#' the function will not perform any action. The options are saved in a YAML file.
+#'
+#' @return
+#' Returns `TRUE` if the options were successfully saved, `FALSE` otherwise.
+#'
+#' @examples
+#' \dontrun{
+#' saveOptions()
+#' }
+#'
+#' @export
+#' 
+#' @keywords internal
+#' 
+saveOptions <- function() {
+    tryCatch({
+        if (!.isPackageNamespaceLoaded("rappdirs", quietly = TRUE)) {
+            return(invisible(FALSE))
+        }
+            
+        pkgConfigDir <- rappdirs::user_config_dir("rpact")
+        if (!dir.exists(pkgConfigDir)) {
+            dir.create(pkgConfigDir, recursive = TRUE, showWarnings = FALSE)
+        }
+        if (!dir.exists(pkgConfigDir)) {
+            return(invisible(FALSE))
+        }
+        
+        optionNames <- make.names(names(base::options()))
+        optionNames <- optionNames[grepl("^rpact\\.", optionNames)]
+        optionFileContent <- character()
+        for (optionName in optionNames) {
+            optionValue <- getOption(optionName)
+            if (!is.null(optionValue)) {
+                optionFileContent <- c(optionFileContent, paste0(optionName, ": ", optionValue))
+            }
+        }
+        optionsFile <- file.path(pkgConfigDir, "options.yml")
+        cat(optionFileContent, file = optionsFile, sep = "\n")
+        return(invisible(file.exists(optionsFile)))
+    }, error = function(e) {
+        warning("Failed to save rpact options: ", e$message, call. = FALSE)
+        return(invisible(FALSE))
+    })
+}
+
+#' 
+#' @title
+#' Reset Options
+#'
+#' @description
+#' Resets the `rpact` options to their default values.
+#'
+#' @param persist A logical value indicating whether the reset options should be saved persistently.
+#'        If `TRUE`, the options will be saved after resetting. Default is `TRUE`.
+#'
+#' @details
+#' This function resets all `rpact` options to their default values. If the `persist` parameter is set to `TRUE`,
+#' the reset options will be saved to a configuration file.
+#'
+#' @return
+#' Returns `TRUE` if the options were successfully reset, `FALSE` otherwise.
+#'
+#' @examples
+#' \dontrun{
+#' resetOptions()
+#' resetOptions(persist = FALSE)
+#' }
+#'
+#' @export
+#' 
+#' @keywords internal
+#' 
+resetOptions <- function(persist = TRUE) {
+    .assertIsSingleLogical(persist, "persist")
+    tryCatch({
+        optionNames <- make.names(names(base::options()))
+        optionNames <- optionNames[grepl("^rpact\\.", optionNames)]
+        if (length(optionNames) == 0) {
+            return(invisible(TRUE))
+        }
+        
+        for (optionName in optionNames) {
+            eval(parse(text = paste0('base::options("', optionName, '" = NULL)')))
+        }
+        if (persist) {
+            saveOptions()
+        }
+        return(invisible(TRUE))
+    }, error = function(e) {
+        warning("Failed to reset rpact options: ", e$message, call. = FALSE)
+        return(invisible(FALSE))
+    })
+}
+
+.loadOptions <- function() {
+    tryCatch({
+        if (!.isPackageNamespaceLoaded("rappdirs", quietly = TRUE)) { 
+            packageStartupMessage("Package \"rappdirs\" is needed for saving and loading rpact options. ",
+                "Please install using, e.g., install.packages(\"rappdirs\")")
+            return(invisible(FALSE))
+        }
+            
+        pkgConfigDir <- rappdirs::user_config_dir("rpact")
+        if (!dir.exists(pkgConfigDir)) {
+            return(invisible(FALSE))
+        }
+        
+        pkgConfigFile <- file.path(pkgConfigDir, "options.yml")
+        if (!file.exists(pkgConfigFile)) {
+            return(invisible(FALSE))
+        }
+        
+        optionFileContent <- readLines(pkgConfigFile)
+        if (length(optionFileContent) == 0) {
+            return(invisible(TRUE))
+        }
+        
+        optionsList <- list()
+        for (line in optionFileContent) {
+            optionName <- sub(":.*", "", line)
+            if (is.null(optionName) || length(optionName) != 1 || nchar(trimws(optionName)) == 0) {
+                next
+            }
+            
+            optionValue <- sub(".*: ", "", line)
+            if (is.null(optionValue) || length(optionValue) != 1 || nchar(trimws(optionValue)) == 0) {
+                next
+            }
+            
+            optionsList[[optionName]] <- optionValue
+        }
+        
+        if (length(optionsList) == 0) {
+            return(invisible(TRUE))
+        }
+        
+        base::options(optionsList)
+        return(invisible(TRUE))
+    }, error = function(e) {
+        packageStartupMessage("Failed to load and set rpact options: ", e$message)
+        return(invisible(FALSE))
+    })
+}
+
