@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6991 $
-## |  Last changed: $Date: 2023-05-16 14:50:11 +0200 (Di, 16 Mai 2023) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 8361 $
+## |  Last changed: $Date: 2024-11-04 16:27:39 +0100 (Mo, 04 Nov 2024) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_core_utilities.R
@@ -29,8 +29,14 @@ NULL
     return(indices)
 }
 
-.selectTreatmentArms <- function(stage, effectVector, typeOfSelection,
-        epsilonValue, rValue, threshold, selectArmsFunction, survival = FALSE) {
+.selectTreatmentArms <- function(typeOfSelection,
+        epsilonValue,
+        rValue,
+        threshold,
+        selectArmsFunction,
+        selectArmsFunctionArgs,
+        survival = FALSE) {
+    effectVector <- selectArmsFunctionArgs$effectVector
     gMax <- length(effectVector)
 
     if (typeOfSelection != "userDefined") {
@@ -51,21 +57,13 @@ NULL
         selectedArms[effectVector <= threshold] <- FALSE
     } else {
         functionArgumentNames <- .getFunctionArgumentNames(selectArmsFunction, ignoreThreeDots = TRUE)
-        if (length(functionArgumentNames) == 1) {
-            .assertIsValidFunction(
-                fun = selectArmsFunction,
-                funArgName = "selectArmsFunction",
-                expectedArguments = c("effectVector"), validateThreeDots = FALSE
-            )
-            selectedArms <- selectArmsFunction(effectVector)
-        } else {
-            .assertIsValidFunction(
-                fun = selectArmsFunction,
-                funArgName = "selectArmsFunction",
-                expectedArguments = c("effectVector", "stage"), validateThreeDots = FALSE
-            )
-            selectedArms <- selectArmsFunction(effectVector = effectVector, stage = stage)
-        }
+        .assertIsValidFunction(
+            fun = selectArmsFunction,
+            funArgName = "selectArmsFunction",
+            expectedArguments = names(selectArmsFunctionArgs),
+            validateThreeDots = FALSE
+        )
+        selectedArms <- do.call(what = selectArmsFunction, args = selectArmsFunctionArgs[functionArgumentNames])
 
         msg <- paste0(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
@@ -119,7 +117,7 @@ NULL
     separatePValues <- stageResults$separatePValues
     if (intersectionTest == "Dunnett") {
         subjectsPerStage <- stageResults[[ifelse(
-            !is.null(stageResults[["subjectsPerStage"]]), "subjectsPerStage", "eventsPerStage"
+            !is.null(stageResults[["subjectsPerStage"]]), "subjectsPerStage", "cumulativeEventsPerStage"
         )]]
         testStatistics <- stageResults$testStatistics
     } else {
@@ -185,13 +183,14 @@ NULL
                 }
             }
 
+            criticalValues <- .getCriticalValues(design)
             if (.isTrialDesignFisher(design)) {
-                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] <= design$criticalValues[k])
+                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] <= criticalValues[k])
                 if (k < kMax) {
                     futilityIntersections[i, k] <- (adjustedStageWisePValues[i, k] >= design$alpha0Vec[k])
                 }
             } else if (.isTrialDesignInverseNormal(design)) {
-                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] >= design$criticalValues[k])
+                rejectedIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] >= criticalValues[k])
                 if (k < kMax) {
                     futilityIntersections[i, k] <- (overallAdjustedTestStatistics[i, k] <= design$futilityBounds[k])
                 }
@@ -222,7 +221,7 @@ NULL
 
         if (k < kMax) {
             futilityStop[k] <- all(futility[stageResults$selectedArms[1:gMax, k], k])
-            if (all(stageResults$selectedArms[1:gMax, k + 1] == FALSE)) {
+            if (all(!stageResults$selectedArms[1:gMax, k + 1], na.rm = TRUE)) {
                 futilityStop[k] <- TRUE
             }
         }
@@ -290,7 +289,7 @@ NULL
     signedOverallTestStatistics[, 2] <- sqrt(informationAtInterim) *
         testStatistics[, 1] + sqrt(1 - informationAtInterim) * testStatistics[, 2]
 
-    if (all(stageResults$selectedArms[1:gMax, 2] == FALSE)) {
+    if (all(!stageResults$selectedArms[1:gMax, 2], na.rm = TRUE)) {
         futilityStop <- TRUE
     }
 
@@ -307,7 +306,7 @@ NULL
             }
             return(innerProduct * dnorm(x))
         }
-        conditionalErrorRate[i, 1] <- 1 - integrate(integrand, lower = -Inf, upper = Inf)$value
+        conditionalErrorRate[i, 1] <- 1 - stats::integrate(integrand, lower = -Inf, upper = Inf)$value
 
         if (!all(is.na(separatePValues[indices[i, ] == 1, 2]))) {
             if (secondStageConditioning) {
@@ -327,7 +326,7 @@ NULL
                     }
                     return(innerProduct * dnorm(x))
                 }
-                secondStagePValues[i, 2] <- 1 - integrate(integrand, lower = -Inf, upper = Inf)$value
+                secondStagePValues[i, 2] <- 1 - stats::integrate(integrand, lower = -Inf, upper = Inf)$value
             } else {
                 maxTestStatistic <- max(signedTestStatistics[indices[i, ] == 1, 2], na.rm = TRUE)
                 integrand <- function(x) {
@@ -340,7 +339,7 @@ NULL
                     }
                     return(innerProduct * dnorm(x))
                 }
-                secondStagePValues[i, 2] <- 1 - integrate(integrand, lower = -Inf, upper = Inf)$value
+                secondStagePValues[i, 2] <- 1 - stats::integrate(integrand, lower = -Inf, upper = Inf)$value
             }
         }
 
@@ -384,6 +383,7 @@ NULL
         omegaMaxVector = NA_real_, # survival only
         gED50,
         slope,
+        doseLevels,
         intersectionTest,
         stDev = NA_real_, # means only
         directionUpper = NA, # rates + survival only
@@ -468,11 +468,11 @@ NULL
     effectMeasure <- .assertIsValidEffectMeasure(effectMeasure)
 
     if (endpoint == "means") {
-        simulationResults <- SimulationResultsMultiArmMeans(design, showStatistics = showStatistics)
+        simulationResults <- SimulationResultsMultiArmMeans$new(design, showStatistics = showStatistics)
     } else if (endpoint == "rates") {
-        simulationResults <- SimulationResultsMultiArmRates(design, showStatistics = showStatistics)
+        simulationResults <- SimulationResultsMultiArmRates$new(design, showStatistics = showStatistics)
     } else if (endpoint == "survival") {
-        simulationResults <- SimulationResultsMultiArmSurvival(design, showStatistics = showStatistics)
+        simulationResults <- SimulationResultsMultiArmSurvival$new(design, showStatistics = showStatistics)
     }
 
     gMax <- activeArms
@@ -505,8 +505,14 @@ NULL
 
     if (endpoint == "means") {
         effectMatrix <- .assertIsValidEffectMatrixMeans(
-            typeOfShape = typeOfShape, effectMatrix = effectMatrix,
-            muMaxVector = muMaxVector, gED50 = gED50, gMax = gMax, slope = slope
+            simulationResults = simulationResults,
+            typeOfShape = typeOfShape, 
+            effectMatrix = effectMatrix,
+            muMaxVector = muMaxVector, 
+            gED50 = gED50, 
+            gMax = gMax, 
+            slope = slope,
+            doseLevels = doseLevels
         )
         if (typeOfShape == "userDefined") {
             muMaxVector <- effectMatrix[, gMax]
@@ -544,8 +550,15 @@ NULL
         .setValueAndParameterType(simulationResults, "piControlH1", piControlH1, NA_real_)
 
         effectMatrix <- .assertIsValidEffectMatrixRates(
-            typeOfShape = typeOfShape, effectMatrix = effectMatrix,
-            piMaxVector = piMaxVector, piControl = piControl, gED50 = gED50, gMax = gMax, slope = slope
+            simulationResults = simulationResults,
+            typeOfShape = typeOfShape, 
+            effectMatrix = effectMatrix,
+            piMaxVector = piMaxVector, 
+            piControl = piControl, 
+            gED50 = gED50, 
+            gMax = gMax, 
+            slope = slope,
+            doseLevels = doseLevels
         )
 
         if (typeOfShape == "userDefined") {
@@ -556,7 +569,16 @@ NULL
             simulationResults$.setParameterType("piMaxVector", C_PARAM_DERIVED)
         }
     } else if (endpoint == "survival") {
-        effectMatrix <- .assertIsValidEffectMatrixSurvival(typeOfShape, effectMatrix, omegaMaxVector, gED50, gMax, slope)
+        effectMatrix <- .assertIsValidEffectMatrixSurvival(
+            simulationResults = simulationResults,
+            typeOfShape = typeOfShape, 
+            effectMatrix = effectMatrix,
+            omegaMaxVector = omegaMaxVector, 
+            gED50 = gED50, 
+            gMax = gMax, 
+            slope = slope,
+            doseLevels = doseLevels
+        )
         if (typeOfShape == "userDefined") {
             omegaMaxVector <- effectMatrix[, gMax]
         }
@@ -577,7 +599,7 @@ NULL
         .assertValuesAreStrictlyIncreasing(plannedEvents, "plannedEvents")
         .setValueAndParameterType(simulationResults, "plannedEvents", plannedEvents, NA_real_)
     }
-
+    
     .assertIsValidThreshold(threshold, gMax)
 
     if (endpoint %in% c("means", "rates")) {
@@ -813,7 +835,6 @@ NULL
         )
     }
 
-    .setValueAndParameterType(simulationResults, "effectMatrix", t(effectMatrix), NULL)
     if (endpoint %in% c("means", "rates")) {
         .setValueAndParameterType(simulationResults, "plannedSubjects", plannedSubjects, NA_real_)
         .setValueAndParameterType(simulationResults, "minNumberOfSubjectsPerStage",
@@ -860,10 +881,6 @@ NULL
     }
     .setValueAndParameterType(simulationResults, "adaptations", adaptations, rep(TRUE, kMax - 1))
 
-    simulationResults$.setParameterType(
-        "effectMatrix",
-        ifelse(typeOfShape == "userDefined", C_PARAM_USER_DEFINED, C_PARAM_DEFAULT_VALUE)
-    )
     .setValueAndParameterType(simulationResults, "activeArms", as.integer(activeArms), 3L)
     if (typeOfShape == "sigmoidEmax") {
         .setValueAndParameterType(simulationResults, "gED50", gED50, NA_real_)
