@@ -13,9 +13,9 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
-## |  Last changed by: $Author: pahlke $
+## |  File version: $Revision: 8449 $
+## |  Last changed: $Date: 2024-12-10 09:39:04 +0100 (Tue, 10 Dec 2024) $
+## |  Last changed by: $Author: wassmer $
 ## |
 
 #' @include f_simulation_multiarm.R
@@ -39,7 +39,7 @@ NULL
     if (!is.na(conditionalPower)) {
         if (any(selectedArms[1:gMax, stage + 1], na.rm = TRUE)) {
             if (is.na(thetaH1)) {
-                if (directionUpper) {
+                if (is.na(directionUpper) || isTRUE(directionUpper)) {
                     thetaStandardized <- log(max(min(
                         overallEffects[selectedArms[1:gMax, stage + 1], stage],
                         na.rm = TRUE
@@ -51,11 +51,10 @@ NULL
                     ), 1 - 1e-07))
                 }
             } else {
-                if (directionUpper) {
-                    thetaStandardized <- log(max(thetaH1, 1 + 1e-07))
-                } else {
-                    thetaStandardized <- log(min(thetaH1, 1 - 1e-07))
-                }
+                thetaStandardized <- log(min(
+                    thetaH1,
+                    1 + ifelse(is.na(directionUpper) || isTRUE(directionUpper), 1e-07, -1e-07)
+                ))
             }
             if (conditionalCriticalValue[stage] > 8) {
                 newEvents <- maxNumberOfEventsPerStage[stage + 1]
@@ -120,8 +119,7 @@ NULL
     gMax <- length(omegaVector)
     simSurvival <- matrix(NA_real_, nrow = gMax, ncol = kMax)
     overallEffects <- matrix(NA_real_, nrow = gMax, ncol = kMax)
-    eventsPerStage <- matrix(NA_real_, nrow = gMax, ncol = kMax)
-    singleEventsPerStage <- matrix(NA_real_, nrow = gMax + 1, ncol = kMax)
+    cumulativeEventsPerStage <- matrix(NA_real_, nrow = gMax, ncol = kMax)
     testStatistics <- matrix(NA_real_, nrow = gMax, ncol = kMax)
     overallTestStatistics <- matrix(NA_real_, nrow = gMax, ncol = kMax)
     separatePValues <- matrix(NA_real_, nrow = gMax, ncol = kMax)
@@ -141,15 +139,15 @@ NULL
         for (treatmentArm in 1:gMax) {
             if (selectedArms[treatmentArm, k]) {
                 if (k == 1) {
-                    eventsPerStage[treatmentArm, k] <- plannedEvents[k] *
+                    cumulativeEventsPerStage[treatmentArm, k] <- plannedEvents[k] *
                         (allocationRatioPlanned[k] * omegaVector[treatmentArm] + 1) /
                         (allocationRatioPlanned[k] * sum(omegaVector) + 1)
                 } else {
-                    eventsPerStage[treatmentArm, k] <- (plannedEvents[k] - plannedEvents[k - 1]) *
+                    cumulativeEventsPerStage[treatmentArm, k] <- (plannedEvents[k] - plannedEvents[k - 1]) *
                         (allocationRatioPlanned[k] * omegaVector[treatmentArm] + 1) /
                         (allocationRatioPlanned[k] * sum(omegaVector[selectedArms[, k]]) + 1)
                 }
-                if (eventsPerStage[treatmentArm, k] > 0) {
+                if (cumulativeEventsPerStage[treatmentArm, k] > 0) {
                     testStatistics[treatmentArm, k] <- stats::rnorm(1, 0, 1)
                 }
             }
@@ -174,17 +172,17 @@ NULL
         for (treatmentArm in 1:gMax) {
             if (selectedArms[treatmentArm, k]) {
                 testStatistics[treatmentArm, k] <- testStatistics[treatmentArm, k] +
-                    (2 * directionUpper - 1) * log(omegaVector[treatmentArm]) * sqrt(eventsPerStage[treatmentArm, k]) *
+                    (2 * directionUpper - 1) * log(omegaVector[treatmentArm]) * sqrt(cumulativeEventsPerStage[treatmentArm, k]) *
                         sqrt(allocationRatioPlanned[k]) / (1 + allocationRatioPlanned[k])
 
                 separatePValues[treatmentArm, k] <- 1 - stats::pnorm(testStatistics[treatmentArm, k])
 
-                overallTestStatistics[treatmentArm, k] <- sqrt(eventsPerStage[treatmentArm, 1:k]) %*%
-                    testStatistics[treatmentArm, 1:k] / sqrt(sum(eventsPerStage[treatmentArm, 1:k]))
+                overallTestStatistics[treatmentArm, k] <- sqrt(cumulativeEventsPerStage[treatmentArm, 1:k]) %*%
+                    testStatistics[treatmentArm, 1:k] / sqrt(sum(cumulativeEventsPerStage[treatmentArm, 1:k]))
 
                 overallEffects[treatmentArm, k] <- exp((2 * directionUpper - 1) * overallTestStatistics[treatmentArm, k] *
                     (1 + allocationRatioPlanned[k]) / sqrt(allocationRatioPlanned[k]) /
-                    sqrt(sum(eventsPerStage[treatmentArm, 1:k])))
+                    sqrt(sum(cumulativeEventsPerStage[treatmentArm, 1:k])))
             }
         }
 
@@ -194,43 +192,63 @@ NULL
             }
 
             # Bonferroni adjustment
-            adjustedPValues[k] <- min(min(separatePValues[, k], na.rm = TRUE) * (colSums(selectedArms)[k]), 1 - 1e-7)
+            adjustedPValues[k] <- min(min(separatePValues[, k], na.rm = TRUE) * (colSums(selectedArms)[k]), 1 - 1e-07)
 
             # conditional critical value to reject the null hypotheses at the next stage of the trial
             if (.isTrialDesignConditionalDunnett(design)) {
                 conditionalCriticalValue[k] <- (.getOneMinusQNorm(design$alpha) - .getOneMinusQNorm(adjustedPValues[k]) *
                     sqrt(design$informationAtInterim)) / sqrt(1 - design$informationAtInterim)
             } else {
+                criticalValues <- .getCriticalValues(design)
                 if (.isTrialDesignFisher(design)) {
-                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
-                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-7))
+                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((criticalValues[k + 1] /
+                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
                 } else {
-                    conditionalCriticalValue[k] <- (design$criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
+                    conditionalCriticalValue[k] <- (criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
                         .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                         sqrt(design$informationRates[k + 1] - design$informationRates[k])
                 }
             }
 
             if (adaptations[k]) {
+                selectArmsFunctionArgs <- list(
+                    effectVector = NULL,
+                    stage = k,
+                    directionUpper = directionUpper,
+                    conditionalPower = conditionalPower,
+                    conditionalCriticalValue = conditionalCriticalValue,
+                    plannedEvents = plannedEvents,
+                    allocationRatioPlanned = allocationRatioPlanned,
+                    selectedArms = selectedArms,
+                    thetaH1 = thetaH1,
+                    overallEffects = overallEffects
+                )
+
+                args <- list(
+                    typeOfSelection = typeOfSelection,
+                    epsilonValue = epsilonValue,
+                    rValue = rValue,
+                    threshold = threshold,
+                    selectArmsFunction = selectArmsFunction,
+                    selectArmsFunctionArgs = NULL,
+                    survival = TRUE
+                )
+
                 if (effectMeasure == "testStatistic") {
-                    selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(k, overallTestStatistics[, k],
-                        typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction,
-                        survival = TRUE
-                    ))
+                    selectArmsFunctionArgs$effectVector <- overallTestStatistics[, k]
                 } else if (effectMeasure == "effectEstimate") {
-                    if (directionUpper) {
-                        selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(k, overallEffects[, k],
-                            typeOfSelection, epsilonValue, rValue, threshold, selectArmsFunction,
-                            survival = TRUE
-                        ))
+                    if (is.na(directionUpper) || isTRUE(directionUpper)) {
+                        selectArmsFunctionArgs$effectVector <- overallEffects[, k]
                     } else {
-                        selectedArms[, k + 1] <- (selectedArms[, k] & .selectTreatmentArms(k, 1 / overallEffects[, k],
-                            typeOfSelection, epsilonValue, rValue, 1 / threshold, selectArmsFunction,
-                            survival = TRUE
-                        ))
+                        selectArmsFunctionArgs$effectVector <- 1 / overallEffects[, k]
+                        args$threshold <- 1 / threshold
                     }
                 }
 
+                args$selectArmsFunctionArgs <- selectArmsFunctionArgs
+
+                selectedArms[, k + 1] <- (selectedArms[, k] & do.call(.selectTreatmentArms, args))
+
                 newEvents <- calcEventsFunction(
                     stage = k + 1, # to be consistent with non-multiarm situation, cf. line 38
                     directionUpper = directionUpper,
@@ -274,7 +292,7 @@ NULL
     }
 
     return(list(
-        eventsPerStage = eventsPerStage,
+        cumulativeEventsPerStage = cumulativeEventsPerStage,
         plannedEvents = plannedEvents,
         allocationRatioPlanned = allocationRatioPlanned,
         overallEffects = overallEffects,
@@ -315,7 +333,7 @@ NULL
 #'        if \code{correlationComputation = "null"}, a constant correlation matrix valid
 #'        under the null, i.e., not accounting for the alternative is used,
 #'         default is \code{"alternative"}.
-#' @inheritParams param_typeOfShape
+#' @inheritParams param_typeOfShapeSurvival
 #' @inheritParams param_typeOfSelection
 #' @inheritParams param_design_with_default
 #' @inheritParams param_directionUpper
@@ -332,6 +350,7 @@ NULL
 #' @inheritParams param_epsilonValue
 #' @inheritParams param_gED50
 #' @inheritParams param_slope
+#' @inheritParams param_doseLevels
 #' @inheritParams param_seed
 #' @inheritParams param_three_dots
 #' @inheritParams param_showStatistics
@@ -377,8 +396,9 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
         omegaMaxVector = seq(1, 2.6, 0.4), # C_RANGE_OF_HAZARD_RATIOS_DEFAULT
         gED50 = NA_real_,
         slope = 1,
+        doseLevels = NA_real_,
         intersectionTest = c("Dunnett", "Bonferroni", "Simes", "Sidak", "Hierarchical"), # C_INTERSECTION_TEST_MULTIARMED_DEFAULT
-        directionUpper = TRUE, # C_DIRECTION_UPPER_DEFAULT
+        directionUpper = NA, # C_DIRECTION_UPPER_DEFAULT
         adaptations = NA,
         typeOfSelection = c("best", "rBest", "epsilon", "all", "userDefined"), # C_TYPE_OF_SELECTION_DEFAULT
         effectMeasure = c("effectEstimate", "testStatistic"), # C_EFFECT_MEASURE_DEFAULT
@@ -418,6 +438,9 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
 
     calcEventsFunctionIsUserDefined <- !is.null(calcEventsFunction)
 
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper, 
+        design, objectType = "power", userFunctionCallEnabled = TRUE)
+    
     simulationResults <- .createSimulationResultsMultiArmObject(
         design                      = design,
         activeArms                  = activeArms,
@@ -426,6 +449,7 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
         omegaMaxVector              = omegaMaxVector, # survival only
         gED50                       = gED50,
         slope                       = slope,
+        doseLevels                  = doseLevels,
         intersectionTest            = intersectionTest,
         directionUpper              = directionUpper, # rates + survival only
         adaptations                 = adaptations,
@@ -634,7 +658,7 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
                     dataArmNumber[index] <- g
                     dataAlternative[index] <- omegaMaxVector[i]
                     dataEffect[index] <- effectMatrix[i, g]
-                    dataNumberOfEvents[index] <- round(stageResults$eventsPerStage[g, k], 1)
+                    dataNumberOfEvents[index] <- round(stageResults$cumulativeEventsPerStage[g, k], 1)
                     dataRejectPerStage[index] <- closedTest$rejected[g, k]
                     dataTestStatistics[index] <- stageResults$testStatistics[g, k]
                     dataSuccessStop[index] <- closedTest$successStop[k]
@@ -699,15 +723,24 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
         simulationResults$conditionalPowerAchieved <- simulatedConditionalPower
     }
 
-    simulationResults$eventsPerStage <- .convertStageWiseToOverallValues(simulatedSingleEventsPerStage)
-    for (g in (1:gMax)) {
-        simulationResults$eventsPerStage[, , g] <- simulationResults$eventsPerStage[, , g] +
-            simulationResults$eventsPerStage[, , gMax + 1]
+    simulationResults$cumulativeEventsPerStage <- .convertStageWiseToOverallValues(simulatedSingleEventsPerStage)
+    for (g in 1:gMax) {
+        simulationResults$cumulativeEventsPerStage[, , g] <- simulationResults$cumulativeEventsPerStage[, , g] +
+            simulationResults$cumulativeEventsPerStage[, , gMax + 1]
     }
-    simulationResults$eventsPerStage <- .removeLastEntryFromArray(simulationResults$eventsPerStage)
+    simulationResults$cumulativeEventsPerStage <- .removeLastEntryFromArray(simulationResults$cumulativeEventsPerStage)
+    .addDeprecatedFieldValues(simulationResults, "eventsPerStage", simulationResults$cumulativeEventsPerStage)
 
-    simulationResults$singleNumberOfEventsPerStage <- simulatedSingleEventsPerStage
-    simulationResults$.setParameterType("singleNumberOfEventsPerStage", C_PARAM_GENERATED)
+    simulationResults$singleEventsPerStage <- simulatedSingleEventsPerStage
+    for (g in 1:gMax) {
+        simulationResults$singleEventsPerStage[, , g] <- simulationResults$singleEventsPerStage[, , g] +
+            simulationResults$singleEventsPerStage[, , gMax + 1]
+    }
+    simulationResults$singleEventsPerStage <- .removeLastEntryFromArray(simulationResults$singleEventsPerStage)
+
+    simulationResults$singleEventsPerArmAndStage <- simulatedSingleEventsPerStage
+    simulationResults$.setParameterType("singleEventsPerArmAndStage", C_PARAM_GENERATED)
+    .addDeprecatedFieldValues(simulationResults, "singleNumberOfEventsPerStage", simulatedSingleEventsPerStage)
 
     simulationResults$expectedNumberOfEvents <- expectedNumberOfEvents
 
